/* 地图组件: mapId: 地图组件id名
* data数据集，name当前省市区名称，splitList分隔区间，mapType地图渲染的地区,mapJson地区的json数据集, 全国时不传
* */
function mapEchart(mapId,data,name,splitList,mapType,mapJson = '') {
    let mapChart = echarts.init(document.getElementById(mapId));
    var option = {
        tooltip: {
            textStyle: {color: "#ffffff"},                 // 提示标签字体颜色
            formatter: function (value) {
                const val = value.data.value
                return val === 0 ? `${value.seriesName}<br/>${value.data.name}: -` :
                    `${value.seriesName}<br/>${value.data.name}: ${val}`
            }
        },
        visualMap: {
            show: false,
            splitList: splitList,
            bottom: 25,
            left: 'center',
            itemWidth: 50,
            color: ['#0153B7','#1180EC','#38A0FF','#71C1FF'],
            formatter: function(value){                    // 标签的格式化工具
                return '';                                 // 范围标签显示内容
            },
            align: 'right',
            orient: 'horizontal',
        },
        series: [
            {
                name: name,
                type: 'map',
                mapType: mapType,
                label: {
                    normal: {
                        show: false,                       // 显示省份标签
                    },
                    emphasis: {
                        show: false,                       // 对应的鼠标悬浮效果
                    }
                },
                emphasis: {
                    show: false,
                    itemStyle: {                           // 选择区域显示颜色
                        areaColor: '#fff100'
                    }
                },
                itemStyle: {
                    normal: {
                        borderColor:'#e6e6e6',
                        label: {
                            show: false
                        }
                    },
                },
                top: 10,
                data: data
            }
        ],
    };
    mapJson !== '' ? echarts.registerMap(mapType, mapJson) : '';   // 全国时，不存在
    mapChart.setOption(option);
    mapChart.on('click',(params) => {
        console.log('地图区域点击params：');
        console.log(params);
    })
}
/* 绘制折线图组件: 单、双折线图同时支持，根据series数组长度设置 
* id: 绘制组件id名，xData：横坐标轴数据数组，series：series设置数据数组，legend: 图例名数组
* legendSet: 设置图例的位置（非必传）
* zoomSet: 设置手柄的起始结束点（非必传）, 默认：null，存在时：[xData.length, limitLen] 
* */
function lineEchart(id, xData, series, legend, legendSet, zoomSet) {
    let lineEchart = echarts.init(document.getElementById(id));     // 获取绘制折线图的区域id
    lineEchart.clear();                                             // 先清除原绘制折线，再重新绘制填充，避免污染
    let legendSet = legendSet ? legendSet : [5,10];                 // 设置图例的属性
    let zoomSet = dataZoomStartEnd(zoomSet);                        // 设置手柄的起始结束点
    let seriesArr = [];                                             // 设置折线图属性配置项数组
    series.forEach((item, idx) => {
        let setting = {
            type: 'line',
            name: legend[idx],                     // 图例名称
            data: item.data,
            symbolSize: 10,
            symbol: 'circle',
            itemStyle: {
                normal: {
                    color: item.color ? item.color : '#1D95F4',
                    borderColor: '#ffffff',
                    barBorderRadius: 1,
                    borderWidth: 2
                }
            },
            lineStyle: {
                normal: {
                    color: item.color ? item.color : '#1D95F4',
                    width: 2
                }
            },
            smooth: true
        }           
        seriesArr.push(setting);
    });
    let option = {
        tooltip: {
            trigger: 'axis',
            axisPointer: {
                type: 'line'
            }
        },
        legend: {
            data: legend,
            bottom: legendSet[0],            // 与外部容器之间的距离
            itemGap: legendSet[1],           // 每一项之间的距离
            // selectedMode: false,          // 控制图例点击是否展示对应的折线图展示、隐藏
            width: 240
        },
        grid: {
            top: '13%',                 // 网格线: 即折线图距顶位置
            left: '3%',
            right: '4%',
            bottom: '20%',
            containLabel: true
        },
        xAxis: [
            {
                type: 'category',
                data: xData,
                axisLine: {
                    lineStyle: {
                        color: '#90979c',
                    }
                },
                splitLine: {
                    show: false
                },
                axisTick: {
                    show: true
                },
                splitArea: {
                    show: false
                },
                axisLabel: {
                    interval: 0,
                    rotate: 40,
                    // color: '#000000',
                    // formatter: (val) => {
                    //     if (val && val.length > 6) return val.substring(0, 6) + '...'
                    //     else return val
                    // }
                }
            }
        ],
        yAxis: [
            {
                name: '',
                type: 'value',
                axisLine: { show: false },
                axisTick: {
                    show: false,
                },
                axisLabel: {
                    margin: 2,
                    formatter: function (value) {
                        if (value >= 10000 && value < 100000000) {
                            value = value / 10000 + '万'
                        } else if (value >= 100000000) {
                            value = value / 100000000 + '亿'
                        }
                        return value
                    }
                    // formatter: (val) => {
                    //     if (Number(val) >= 10000) return (Number(val) / 10000).toFixed(0) + '万'
                    //     else return val
                    // }
                }
            }
        ],
        dataZoom: [{
            show: true,
            type: "slider",                           // 类型
            height: 20,
            bottom: 8,
            startValue: zoomSet[0],
			endValue: zoomSet[1],
            handleStyle: {                            // 滚动条手柄的样式
                color: "#40bcf9",
                borderColor: "#1fb2fb"
            },
            backgroundColor: "#e2f3ff",               // 背景
            dataBackground: {                         // 数据背景
                lineStyle: {
                    color: "#000000"
                },
                areaStyle: {
                    color: "#d4d9dd"
                }
            },
            fillerColor: "rgba(31,178,251,0.2)",      // 被start和end遮住的背景
        }],
        series: seriesArr,
    }
    lineEchart.setOption(option);
}
// 获取手柄图例初始固定区间段
function dataZoomStartEnd(zoomSet){
    let curHour = dayjs().get('hour'), retHour, resData = [];
    if(zoomSet && zoomSet.length > 0){
        retHour = zoomSet[0] > zoomSet[1] ? zoomSet[0] - zoomSet[1] : 0;
        resData = [retHour, zoomSet[0]-1];
    }else{                      // 横坐标: 日期小时时间
        if(curHour<=5){
            retHour = 5;
        }else{
            retHour = curHour+1;
        }
        resData = [retHour-5, retHour];
    }
    return resData;
}
/* 绘制(含参考线)折线图组件: eg: 历史最高收寄量参考线, id: 绘制组件id名
* xData：横坐标轴数据数组，series：series设置数据数组，legend: 图例名数组，historyHighObj: 参考线数据信息
* legendSet: 设置图例的位置（非必传）
* zoomSet: 设置手柄的起始结束点（非必传）, 默认：null，存在时：[xData.length, limitLen] limitLen：7 || 10之类的
* */ 
function ckLineEchart(id, xData, series, legend, legendSet, historyHighObj, zoomSet) {
    let ckLineEchart = echarts.init(document.getElementById(id));    // 获取绘制折线图的区域id
    ckLineEchart.clear();                                            // 先清除原绘制折线，再重新绘制填充，避免污染  
    let legendSet = legendSet ? legendSet : [5,10];                  // 设置图例的属性
    let zoomSet = dataZoomStartEnd(zoomSet);                         // 设置手柄的起始结束点
    let seriesArr = [];                                              // 设置折线图属性配置项数组
    series.forEach((item, idx) => {
        let setting = {
            type: 'line',
            name: legend[idx],                     // 图例名称
            data: item.data,
            symbolSize: 10,
            symbol: item.symbol ? item.symbol : 'circle',             // 折线图是否存在拐点
            itemStyle: {
                normal: {
                    color: item.color ? item.color : '#1D95F4',
                    borderColor: '#ffffff',
                    barBorderRadius: 1,
                    borderWidth: 2
                }
            },
            lineStyle: {
                normal: {
                    color: item.color ? item.color : '#1D95F4',
                    width: 2
                }
            },
            smooth: true
        }           
        seriesArr.push(setting);
    });
    let option = {
        tooltip: {
            confine: true,              // 设置tooltip展示位置自适应，不超出echart框
            trigger: 'axis',
            axisPointer: {
                type: 'line'
            },
			formatter: function(params){
				if(params[1]&&params[0]){
					var seriesName = params[0].seriesName;
					if (historyHighObj.dateType == '12周内' || historyHighObj.dateType == '12月内') {
						seriesName = "日均处理量";
					}
					return `${ params[0].name} <br/>
							${ seriesName }: ${ params[0].value} <br/>
							${params[1].seriesName }: ${ params[1].value}<br/>
                            (历史最高收寄量日期: ${historyHighObj.historyDay})`
				}else{
					return ` ${ params[0].name} <br/>
							${ params[0].seriesName }: ${ params[0].value} <br/>`
				}
			}
        },
        legend: {
            data: legend,
            bottom: legendSet[0],
            itemGap: legendSet[1],
            width: 240
        },
        grid: {
            top: '13%',
            left: '3%',
            right: '4%',
            bottom: '20%',
            containLabel: true
        },
        xAxis: [
            {
                type: 'category',
                data: xData,
                axisLine: {
                    lineStyle: {
                        color: '#90979c'
                    }
                },
                splitLine: {
                    show: false
                },
                axisTick: {
                    show: true
                },
                splitArea: {
                    show: false
                },
                axisLabel: {
                    interval: 0,
                    rotate: 40
                }
            }
        ],
        yAxis: [
            {
                name: '',
                type: 'value',
                axisLine: {show: false},
                axisTick: {
                    show: false
                },
                axisLabel: {
                    margin: 2,
                    formatter: function (value) {
                        if (value >= 10000 && value < 100000000) {
                            value = value / 10000 + '万'
                        } else if (value >= 100000000) {
                            value = value / 100000000 + '亿'
                        }
                        return value
                    }
                }
            }
        ],
        dataZoom: [{
            show: true,
            type: "slider",                           // 类型
            height: 20,
            bottom: 8,
            startValue: zoomSet[0],
            endValue: zoomSet[1],
            handleStyle: {                            // 滚动条手柄的样式
                color: "#40bcf9",
                borderColor: "#1fb2fb"
            },
            backgroundColor: "#e2f3ff",               // 背景
            dataBackground: {                         // 数据背景
                lineStyle: {
                    color: "#000000"
                },
                areaStyle: {
                    color: "#d4d9dd"
                }
            },
            fillerColor: "rgba(31,178,251,0.2)",       // 被start和end遮住的背景
        }],
        series: seriesArr,
    }
    ckLineEchart.setOption(option);
}
/* 绘制柱状图组件: 单、多柱图同时支持，根据series数组长度设置 
* id: 绘制组件id名，xData：横坐标轴数据数组，series：series设置数据数组，legend: 图例名数组
* legendSet: 设置图例的位置（非必传）
* zoomSet: 设置手柄的起始结束点（非必传）, 默认：null，存在时：[xData.length, limitLen] 
* */
function barEchart(id, xData, series, legend, legendSet, zoomSet) {
    let barEchart = echarts.init(document.getElementById(id));      // 获取绘制折线图的区域id
    barEchart.clear();                                              // 先清除原绘制折线，再重新绘制填充，避免污染
    let legendSet = legendSet ? legendSet : [5,10];                 // 设置图例的属性
    let zoomSet = dataZoomStartEnd(zoomSet);                        // 设置手柄的起始结束点
    let seriesArr = [];                                             // 设置折线图属性配置项数组
    series.forEach((item, idx) => {
        let setting = {
            type: 'bar',                           // 柱状图类型
            name: legend[idx],                     // 图例名称
            data: item.data,
            symbolSize: 10,
            symbol: 'circle',
            itemStyle: {
                normal: {
                    color: item.color ? item.color : '#1D95F4',
                    borderColor: '#ffffff',
                    barBorderRadius: 1,
                    borderWidth: 2
                }
            },
            lineStyle: {
                normal: {
                    color: item.color ? item.color : '#1D95F4',
                    width: 2
                }
            },
            smooth: true
        }           
        seriesArr.push(setting);
    });
    let option = {
        tooltip: {
            trigger: 'axis',
            axisPointer: {
                type: 'line'
            }
        },
        legend: {
            data: legend,
            bottom: legendSet[0],            // 与外部容器之间的距离
            itemGap: legendSet[1],           // 每一项之间的距离
            width: 240
        },
        grid: {
            top: '13%',                 // 网格线: 即折线图距顶位置
            left: '3%',
            right: '4%',
            bottom: '20%',
            containLabel: true
        },
        xAxis: [
            {
                type: 'category',
                data: xData,
                axisLine: {
                    lineStyle: {
                        color: '#90979c',
                    }
                },
                splitLine: {
                    show: false
                },
                axisTick: {
                    show: true
                },
                splitArea: {
                    show: false
                },
                axisLabel: {
                    interval: 0,
                    rotate: 40,
                    // color: '#000000',
                    // formatter: (val) => {
                    //     if (val && val.length > 6) return val.substring(0, 6) + '...'
                    //     else return val
                    // }
                }
            }
        ],
        yAxis: [
            {
                name: '',
                type: 'value',
                axisLine: { show: false },
                axisTick: {
                    show: false,
                },
                axisLabel: {
                    margin: 2,
                    formatter: function (value) {
                        if (value >= 10000 && value < 100000000) {
                            value = value / 10000 + '万'
                        } else if (value >= 100000000) {
                            value = value / 100000000 + '亿'
                        }
                        return value
                    }
                    // formatter: (val) => {
                    //     if (Number(val) >= 10000) return (Number(val) / 10000).toFixed(0) + '万'
                    //     else return val
                    // }
                }
            }
        ],
        dataZoom: [{
            show: true,
            type: "slider",                           // 类型
            height: 20,
            bottom: 8,
            startValue: zoomSet[0],
			endValue: zoomSet[1],
            handleStyle: {                            // 滚动条手柄的样式
                color: "#40bcf9",
                borderColor: "#1fb2fb"
            },
            backgroundColor: "#e2f3ff",               // 背景
            dataBackground: {                         // 数据背景
                lineStyle: {
                    color: "#000000"
                },
                areaStyle: {
                    color: "#d4d9dd"
                }
            },
            fillerColor: "rgba(31,178,251,0.2)",      // 被start和end遮住的背景
        }],
        series: seriesArr,                                              
    }
    barEchart.setOption(option);
}
/* 绘制球形图组件: id: 绘制组件id名,
* data：填充数据数组，color：填充颜色色系，isOnLine: 是否数据不存在，为‘--’
* */
function sphereEchart(id, data, color, isOnLine = true) {
    var chart = new G2.Chart({
        container: id,
        forceFit: true,
        height: 100,
        padding: 0
    });
    chart.source(data, { value: { min: 0, max: 100 } });
    chart.legend(false);
    chart.axis(false);
    chart.interval().position('gender*value').color(color).shape('liquid-fill-gauge').style({
        lineWidth: 2,
        opacity: .5
    });
    data.forEach(function(row) {
        chart.tooltip(false);
        chart.guide().text({
            top: true,
            position: {
                gender: row.gender,
                value: 50
            },
            content: !isOnLine ? '--' : row.value + '%',
            style: {
                opacity: 0.9,
                fontSize: '17',
                textAlign: 'center',
                fill: row.value >= 60 ? '#FFFFFF' : '#000000'
            }
        });
    });
    chart.render();
}




