// this.defaultDateParams形如defaultP所示
let defaultP = {
	type: 'day',
	dateCode: '2022-04-07',
	support: ["day","week","month"],
	dataMap: {
		day: '2022-04-07',
		month: '2022-03',
		week: '2022-04-03 13',
		sevenDay: '2022-04-07'
	}
}
// 日期选择项控件
Vue.component('jd-datepicker', {
	data(){
		return {
			showDatePicker: false,
			selectShowText: '',
			selectDateType: '',
			selectDateValue: '',
			defaultDateParams: {
				type: 'day',
				dateCode: getRelativetDate('day',0,1),
				support: ["day","week","month"],
				dataMap: {
					day: getRelativetDate('day',0,1),
					month: getRelativetDate('month',0,1),       // 原：月份T-1
					week: setweekStyle(getRelativetDate('week',0,7)),
					sevenDay: getRelativetDate('day',0,1)
				}
			},
			actionFlag: '',
			// 以下为原代码
			active: '',
			tab: [{
				title: '按日',
				name: 'day'
			},
			{
				title: '按周',
				name: 'week'
			},
			{
				title: '按月',
				name: 'month'
			},
			{
				title: '近七天',
				name: 'sevenDay'
			}],
			mapText: {
				'day': 0,
				'week': 1,
				'month': 2,
				'sevenDay': 3,
			},
			nowD:{},
			dataMap: {},                    // 缺省日期
			isTab: true,                    // 是否开启
			activeName: 'day',
			weekVal: '',                    // 周
			weekParam: '',                  // 周
			day: '',                        // 日
			currentMonth: "",               // 月
			sevenNear: '',                  // 七天
			dayPickerOptions: {             // 日禁止
				disabledDate: (time) => {
					var times = Date.now() - 24*60*60*1000;
					return time.getTime() > times ;
				}
			},
			monthPickerOptions: {            // 月禁止
				disabledDate: (time) => {
					const d = new Date();
					let nowYear = d.getFullYear();               // 获取完整的年份(4位);
					let nowMon = d.getMonth() + 1;               // 获取当前月份
					let timeMon = new Date(time).getMonth() + 1;
					let timeYear = new Date(time).getFullYear();
					return timeYear > nowYear || ((nowYear == timeYear) && (timeMon >= nowMon));
				}
			},
			onPicker: {                     // 周禁止
				firstDayOfWeek: 1,                               // 周起始日为星期一
				disabledDate(value) {
					let today = new Date();                      // 获取今天日期
					let d = today.getDay();                      // 计算今天是周几。如果是周天，d=0
					let w = 0;
					if (d === 0) {
						w = 7;
					} else {
						w = d;
					}
					// let endTime = today.setDate(today.getDate() - w); // 7-w 禁止本周以后 包括本周
					let endTime = today.setDate(today.getDate() + (7 - w)) - 7 * 24 * 3600 * 1000;
					return value.getTime() > endTime;             // 不可选本周日以后的时间
				}
			},
			sevenPickerOptions: {           // 七天禁止
				disabledDate: (time) => {
					var times = Date.now()
					return time.getTime() > times;
				},
			},
		}
	},
	props: {
		// 日期组件支持查询的类型
		support: {
			type: String,
			default: 'day,week,month'
		},
		fontColor: {
			type: String,
			default: '#000000'
		},
		fontSize: {
			type: String,
			default: '12px'
		},
		iconSize: {
			type: String,
			default: '15px'
		},
		// 可选,上页传递日期 格式YY-MM-DD
		drillDate:{
			type:String, 
		},
		// 可选,默认展示当天 格式YY-MM-DD
		showCurDay:{
			type:Boolean,
			default:false
		},
		// 是否展示选中日期标识
		noshowDate:{
			type: Boolean,
			default: false
		},
	},
	created() {
		if (this.showCurDay) {
			this.defaultDateParams.dataMap.day = dayjs().format('YYYY-MM-DD');
		};
		this.dataMap = JSON.parse(JSON.stringify(this.defaultDateParams.dataMap)); 
	},
	mounted() {
		this.init();
	},
	directives: {
	    // 指令的定义：注册一个局部的自定义指令 v-focus
	    focus: {               
	        inserted: function (el) {
	            el.querySelector("input").focus();       // 聚焦元素
	        }
	    }
	},
	watch:{
		drillDate(old){
			console.log('下钻日期传递',this.drillDate)
			if(this.drillDate) {
				this.defaultDateParams.dateCode = this.drillDate
				this.makeSelectDate({
					active: this.defaultDateParams.type,
					val: this.defaultDateParams.dateCode
				})
			}
		}
	},
	methods: {
		// 重新加载
		init(type) {
			if(type == null) {
				let val = this.showCurDay ? dayjs().format('YYYY-MM-DD')
					: this.defaultDateParams.dateCode
				if (this.showCurDay) {
					this.dayPickerOptions = { //日禁止
						disabledDate: (time) => {
							return time.getTime() > Date.now();
						}
					}
				}
				if(this.support === 'month'){
					this.$set(this.defaultDateParams, 'type', this.support)
					this.$set(this.defaultDateParams, 'dateCode', dayjs().format('YYYY-MM'))
					this.dataMap.month = dayjs().format('YYYY-MM')
					this.defaultDateParams.dataMap.month=this.dataMap.month
					val = dayjs().format('YYYY-MM')
					this.monthPickerOptions =  { //月禁止
						disabledDate: (time) => {
							const d = new Date();
							let nowYear = d.getFullYear(); //获取完整的年份(4位);
							let nowMon = d.getMonth()+1 ; //获取当前月份()
							let timeMon = new Date(time).getMonth()+1;
							let timeYear = new Date(time).getFullYear();
							return timeYear > nowYear || ((nowYear == timeYear) && (timeMon > nowMon));
						}
					}
				}
				this.makeSelectDate({
					active: this.defaultDateParams.type,
					val: val
				}, 'init')
			} else {
				this.makeSelectDate({
					active: type,
					val: this.defaultDateParams.dataMap[type]
				}, 'init')
			}
			this.setTab(this.defaultDateParams.type ,this.defaultDateParams.support)
		},
		// 获取时间选择器焦点，防止器隐藏
		getFocus() {
			for(let i=0; i<this.$refs[this.active].length; i++){
				// this.$refs[this.active][i].handleClickIcon(); 
				this.$refs[this.active][i].focus();
			}
		},
		// 打开时间控件面板
		ctrlDatePicker() {
			// console.log('support:' + this.support)
			// console.log(this.support.split(','))
			let support = this.support.split(',')
			let support0
			if(-1 == support.findIndex(item => item == this.defaultDateParams.type)) {
				support0 = support[0] ? support[0] : 'day'
			} else {
				support0 = this.defaultDateParams.type
			}
			Vue.set(this.defaultDateParams, 'support', support)
			Vue.set(this.defaultDateParams, 'type', support0)
			Vue.set(this.defaultDateParams, 'dateCode', this.defaultDateParams.dataMap[support0])

			//设置当前tab状态
			this.active = support0
			//设置当前tab个数
			this.setTab(this.active ,this.defaultDateParams.support)
			this.showDatePicker = true	
		},
		// 打开面板之后触发
		openedActionSheet() {
			let p = JSON.stringify(this.defaultDateParams);
			this.setChooseData(p)
		},
		// 返回的时间
		makeSelectDate(params, initType) {
			const { active, val } = params;
			if(active === 'day') {
				params['type'] = 'D'
				params['value'] = val.replace(/\-/g, '.')
				this.selectShowText = val
			} else if(active === 'week') {
				params['type'] = 'W'
				params['value'] = val.weekVal.replace(/\ /g, '.')
				this.selectShowText = val.weekText
			} else if(active === 'month') {
				params['type'] = 'M'
				params['value'] = val.replace(/\-/g, '.')
				this.selectShowText = val
			} else if(active === 'sevenDay') {
				params['type'] = 'S'
				params['value'] = val.replace(/\-/g, '.')
				this.selectShowText = val
			}
			this.selectDateValue = params['value']
			this.selectDateType = params['type']
			this.defaultDateParams.type = active
			this.defaultDateParams.dateCode = this.selectShowText
			this.defaultDateParams.dataMap[active] = this.selectShowText
			if(!initType){                           // 非初始化时候回调
				this.$emit('set-select-date', params)
			}
		},
		// 以下为原代码
		close() {
			Emp.execute('close()');
			this.clear();
		},
		clear() {
			this.day = '';
			this.currentMonth = '';
			this.weekVal = '';
			this.sevenNear = '';
		},
		// 回到默认时间
		reset() {
			this.actionFlag = 'reset';
			var active = this.active;
			this.onClick(active, 'on');
			setTimeout(()=>{
				// 重置actionFlag，防止遗留影响其他操作
				this.actionFlag = ''
			},300);
		},
		onSure() {
			this.actionFlag = 'sure'; // 目前根据reset判断，暂可不去除sure
			var val = '';
			var active = this.active;
			if (active == 'day') {
				val = this.day
			} else if (active == 'month') {
				val = this.currentMonth
			} else if (active == 'week') {
				val = this.weekParam
			} else if (active == 'sevenDay') {
				val = this.sevenNear
			}
			var obj = {}
			obj.val = val
			obj.active = active
			let p = JSON.stringify(obj)
			this.makeSelectDate(obj)
			this.showDatePicker = false
		},
		// 切换点击按钮
		onClick(active, state) {
			this.active = active;
			this.setDefalut(active,state);          // 设置默认值
			this.getFocus();                        // 设置初始日历展开
			return;
		},
		setDefalut(active,state) {
			// console.log(this.actionFlag)
			let dataMap;
			if(this.actionFlag == 'reset'){
				dataMap = this.dataMap;
			} else {
				dataMap = this.defaultDateParams.dataMap;
			}
			// console.log(dataMap)
			// 设置缺省值
			if (active == 'day') {
				this.day = dataMap['day']
			} else if (active == 'month') {
				this.currentMonth = dataMap['month']
			} else if (active == 'week') {
				
				this.weekVal = dataMap['week']
				var year = this.weekVal.split(' ')[0].split('-')[0]
				var num = this.weekVal.split(' ')[1]
				this.weekParam = {
					weekVal: year + " " + num,
					weekText: this.weekVal
				}
			} else if (active == 'sevenDay') {
				this.sevenNear = dataMap['sevenDay']
			}
		},
		dayChange(val) {
			//日显示的值
			this.$refs.day[this.mapText['day']].focus()
		},
		monthChange(val) {
			//月显示的值
			if(this.$refs.month[this.mapText['month']] !== undefined){
				this.$refs.month[this.mapText['month']].handleClickIcon()
			}else{
				this.$refs.month[1] && this.$refs.month[1].focus()
				this.$refs.month[2] && this.$refs.month[2].focus()
				this.$refs.month[3] && this.$refs.month[3].focus()
			}
		},
		sevenDayChange(val) {
			//仅七天显示的值
			if(this.$refs.sevenDay[this.mapText['sevenDay']] !== undefined){
				this.$refs.sevenDay[this.mapText['sevenDay']].handleClickIcon()
			}else{
				this.$refs.sevenDay[2].focus()
				this.$refs.sevenDay[3].focus()
			   
			}
		},
		weekChange(val) {
			//周显示的值
			this.weekVal = this.getWeekStartAndEnd(0, new Date(val))
			this.$nextTick(() => {
				let param = {}
				let week = document.querySelector("#getWeek").value
				//实际的值
				param.weekVal = new Date(val).getFullYear() + " " + week.split(' ')[1]
				param.weekText = week
				this.weekParam = param
				 //月显示的值
				 if(  this.$refs.week[this.mapText['week']] !== undefined){
					this.$refs.week[this.mapText['week']].handleClickIcon()
				}else{
					this.$refs.week[1].focus()
					this.$refs.week[2].focus()
					this.$refs.week[3].focus()
				}
			})
		},
		getWeekStartAndEnd(AddWeekCount, date) {
			//一天的毫秒数
			var millisecond = 1000 * 60 * 60 * 24;
			//获取时间
			var currentDate = date;
			//相对于任意日期AddWeekCount个周的日期
			currentDate = new Date(currentDate.getTime() + (millisecond * 7 * AddWeekCount));
			//返回date是一周中的某一天
			var week = currentDate.getDay();
			//返回date是一个月中的某一天
			var month = currentDate.getDate();
			//从周几开始计算
			var weekNumber = 1
			if (week < weekNumber) {
				var minusDay = 7 - (weekNumber - week)
			} else {
				var minusDay = week - weekNumber
			}
			//获得周的第一天
			var currentWeekFirstDay = new Date(currentDate.getTime() - (millisecond * minusDay));
			//获得周的最后一天
			var currentWeekLastDay = new Date(currentWeekFirstDay.getTime() + (millisecond * 6));
			return currentWeekLastDay
		},
		setTab(silde,support) {
			if(support && typeof(support) === 'object'){
				let map = {
					day: '按日',		
					week: '按周',		
					month: '按月',		
					sevenDay: '近七天',		
				};
				let tabs = [];
				support.forEach(e => {
					tabs.push({
						title: map[e],
						name: e,
					});
				});
				
				this.tab = tabs;
				return;
			}
			if (silde == 'nameLink') { //环节看板无最近七天
				this.tab = [
					{
						title: '按日',
						name: 'day'
					},
					{
						title: '按周',
						name: 'week'
					},
					{
						title: '按月',
						name: 'month'
					}
				]
			} else {
				this.tab = [
					{
						title: '按日',
						name: 'day'
					},
					{
						title: '按周',
						name: 'week'
					},
					{
						title: '按月',
						name: 'month'
					},
					{
						title: '近七天',
						name: 'sevenDay'
					}
				]
			}
		},
		handleState(paramObj){
			//默认选择
			this.$nextTick(()=>{
				this.onClick(paramObj.type, 'on')
			})
		},
		setChooseData(params) {
			var paramObj = JSON.parse(params)
			if (paramObj && paramObj.type == 'day') {
				this.handleState(paramObj)
				this.day = paramObj.dateCode
			} else if (paramObj && paramObj.type == 'month') {
				this.handleState(paramObj)
				this.currentMonth = paramObj.dateCode
			} else if (paramObj && paramObj.type == 'week') {
				this.handleState(paramObj)
				this.weekVal = paramObj.dateCode
			} else if (paramObj && paramObj.type == 'sevenDay') {
				this.handleState(paramObj)
				this.sevenNear = paramObj.dateCode
			}
		}
	},
	template:`
		<div>
			<div class="jd-datepicker" @click="ctrlDatePicker">
				<span v-if="!noshowDate" class="date-showtext" :style="{color: fontColor, fontSize: fontSize }">
					{{selectShowText}}
				</span>
				<span class="date-icon dark" :style="{ width: iconSize, height:iconSize }"></span>
			</div>
			<van-action-sheet v-model="showDatePicker" @opened="openedActionSheet" @click="getFocus">
				<div class="warp">
					<div class="title">
						<!-- <div class="close" @click='close'>取消</div> -->
						<div class="reset" @click.stop='reset'>回到默认时间</div>
						<div style="color: #333333; margin-left: -46px; font-weight: 700;">选择查看时间</div>
						<div class="onSure" @click.stop='onSure'>确定</div>
					</div>
				
					<van-tabs class="blue-van-tabs" v-model="active" @click="onClick" >
						<van-tab v-for="(item,index) in tab" :key="index" :title="item.title" :name="item.name">
							<el-row style="text-align: center;" v-if='item.name =="day"'>
								<el-date-picker :clearable='false' :editable='false' ref="day" @change="dayChange" v-model="day"
									type="date" :picker-options="dayPickerOptions" placeholder="选择日期" format="yyyy-MM-dd"
									value-format="yyyy-MM-dd" >
								</el-date-picker>
							</el-row>
							<el-row style="text-align: center;" v-show='item.name  =="week"'>
								<el-date-picker :clearable='false' id='getWeek' ref="week" @change="weekChange"
									:picker-options="onPicker" v-model="weekVal" value-format="yyyy-MM-dd" type="week"
									format="yyyy-MM-dd WW" placeholder="选择周">
								</el-date-picker>
							</el-row>
							<el-row style="text-align: center;" v-show='item.name  =="month"'>
								<el-date-picker :clearable='false' :editable='false' ref="month" @change="monthChange"
									v-model="currentMonth" type="month" :picker-options='monthPickerOptions' placeholder="选择月"
									format="yyyy-MM" value-format="yyyy-MM">
								</el-date-picker>
							</el-row>
						   
							<el-row style="text-align: center;" v-show='item.name  =="sevenDay"'>
								<el-date-picker :clearable='false' :editable='false' ref="sevenDay" @change="sevenDayChange"
									v-model="sevenNear" type="date" :picker-options='sevenPickerOptions' placeholder="选择日期"
									format="yyyy-MM-dd" value-format="yyyy-MM-dd" >
								</el-date-picker>
							</el-row>
						</van-tab>
					</van-tabs>
				</div>
			</van-action-sheet>
		</div>
	`
})


