// table表格基础组件(不可下钻)
Vue.component('table-basic', {
	data() {
        return {
            // tableData: [],         // table列表数据
        }
    },
	props: {
        // id值：table组件的id值
        idName: {
            type: String,
            required: true
        },
		// table表格列头项信息
		tableColumn: {
			Array,
			default: () => {
				return []
			}
		},
		// 接口返回数据
		tableData: {
			Array,
			default: () => {
				return []
			}
		},
	},
	methods: {
        // 空占位：当返回值为undefined,null,NaN时，此时数据展示用'-'占位
		nullBlank(val) {
			let res = val;
			if(val == undefined || val == null || val == NaN){
				res = '-';
			}
			return res;
		},
		// table列表：td项的展示值
		getSpanValue(val,itemFilter) {
			// console.log('getSpanValue值: '+JSON.stringify(val));
			let res;
			if(itemFilter){
				res = itemFilter(val);
			}else{
				res = this.nullBlank(val);
			}
			return res;
		},
        // 下钻功能：table表格项点击，i：item列项信息，row：行信息
		handleClick(i, row) {
			this.$emit('drilldown', {
				key: i.key,
				row: row
			})
		},
        // table表格: 设置表头样式
        getHeaderClass() {
            return "background: #0197FF; color: #FFFFFF; height: 30px;";
        },
        // table表格: 设置某一列样式
        getColClass({row, column, rowIndex, columnIndex}) {
            if(columnIndex == 0){
                return "color: #0197FF;";
            }else if(columnIndex == 2){
                return "padding-left: 13px; padding-right: 13px;";
            }
        }	
	},
	mounted() {},
	// 渲染组件界面
	template: 
        `<div :id="idName" class="tableBasic">
            <el-table border stripe
                :data="tableData"
                style="width: 100%"
                size="medium"
                :header-cell-style="getHeaderClass"
                :cell-style="getColClass"
            >
                <template v-for="item in tableColumn">
                    <el-table-column :prop="item.key" :align="item.align ? item.align : 'right'"
                        :min-width="item.width" :fixed="item.fixed"
                    >
                        <template slot="header" slot-scope="scope">
                            <div class="table-sort" style="width: 100%;">
                                <span v-html="item.name" class="tableSortSpan"></span>
                            </div>
                        </template>
                        <template slot-scope="scope">
                            <div @click="handleClick(item, scope.row)">
                                <span style="display: block;">
                                    {{getSpanValue(scope.row[item.key])}}
                                </span>
                            </div>
                            <slot v-else :row="scope.row"></slot>
                        </template>
                    </el-table-column>
                </template>   
            </el-table>
        </div>`
});
  