// EchartTable组件: 上面是趋势图，下面是table下钻列表
Vue.component('drillDownEchartTable', {
	data() {
		return {
			radio:'1',
			style1: {
				color: '#0199FF'
			},
			style2: {
				color: '#000000'
			},
			sortType: true,
			upColor: 'red',         // 上升颜色
			downColor: 'green',     // 下降颜色
			sortConfig: {},         // 排序配置项
		}
	},
	props: {
		radio:{
			type: String,
			default: '1'
		},
		// 组件id名
		idName: {
			type: String,
			default: 'chartID'
		},
		// table表格列头项信息
		tablecolumn: {
			Array,
			default: () => {
				return []
			}
		},
		// level层级的title名称: 列名项使用
		title: {
			String,
			default: '省份'
		},
		// 接口返回数据
		list: {
			Array,
			default: () => {
				return []
			}
		},
		// 颜色类型
		colorType: {
			Number,
			default: 1
		},
		// 是否可下钻标识
		isDrillDown: {
			Boolean,
			default: true
		},
		// 是否展示序号标识
		isNo: {
			Boolean,
			default: true
		},
		// 特殊名称
		specialName: {
			Array,
			default: () => {
				return ['总计', '合计', '南航集散', '其他', '全国', '南集', '*']
			}
		},
		// 是否展示总计标识
		showTotal: {
			Boolean,
			default: true
		},
		// 设置table高度
		tableHeight: {
			String,
			default: () => {       // 获取页面高度
				const h = document.documentElement.clientHeight || document.body.clientHeight
				return h;
			}
		},
		// 趋势图名称
		echartName: {
			String,
			default: ''
		},
		// 排序类型
		sortType: {
			String,
			default: ''
		},
		// 默认排序
		defaultSort: {
			String,
			default: () => {
				return {
					prop: 'nameCode',
					order: 'descending'
				}
			}
		},
		// 是否反转标识
		notReverse: {
			Boolean,
			default: true
		},
		// 趋势图选中类型名称： 今日趋势图、历史趋势图
		choiceTypeName: {
			String,
			default: ''
		},
		selectTypeName: {
			String,
			default: ''
		},
		xiazuanName: {
			String,
			default: ''
		},
		// 当前table列表下钻层级的名称
		echartLevelName: {
			String,
			default: ''
		},
		echartsLenged: {
			String,
			default: ''
		},
		section: {
			String,
			default: ''
		},
		isShowLine: {
			Boolean,
			default: false
		},
		// 是否展示备注标识（点击机构名称可查看机构趋势图）
		isShowNote: {
			Boolean,
			default: false
		},
		isShowBox: {
			Boolean,
			default: false
		},
		xzShow: {
			Boolean,
			default: false
		},
		isShowPic: {
			Boolean,
			default: true
		},
		valueMax: {
			String,
			default: null
		},
		// 接口初始返回的今日趋势图（今日）数组
		trendList: {
			Array,
			default: () => {
				return []
			}
		},
		// 接口初始返回的今日趋势图（昨日）数组
		yesTrendList: {
			Array,
			default: () => {
				return []
			}
		},
		// 接口初始返回的历史趋势图数组
		historyList: {
			Array,
			default: () => {
				return []
			}
		},
		// 接口初始返回的原数组
		list_copy: {
			Array,
			default: () => {
				return [{
					name: '北京市',
					value: '36',
					zrtb: 0
				}]
			}
		},
	},
	computed: {
		x_data() {
			this.list = this.sortSpecialInList(this.list);
			const _list = JSON.parse(JSON.stringify(this.list));
			const newList = _list.sort((i, n) => {
				return Number(i.nameCode) - Number(n.nameCode);
			});
			const arr = _list.filter(e => e.name !== '总计' && e.name !== '合计');
			return arr.map(i => i.name);
		},
		value_data() {
			const _list = JSON.parse(JSON.stringify(this.list));
			const newList = _list.sort((i, n) => {
				return Number(i.nameCode) - Number(n.nameCode);
			});
			const arr = _list.filter(e => e.name !== '总计' && e.name !== '合计');
			return arr.map(i => i.value);
		}
	},
	mounted() {
		const h = document.documentElement.clientHeight || document.body.clientHeight;
		document.getElementById(this.idName).style.height = h / 2 + 'px';   // 设置趋势图的高度占可视屏幕的一半
	},
	methods: {
		// 单选选项值变更操作
		radioChange(item) {
			this.$emit('change', {
				item: item,
			})
		},
		// 设置table项的颜色
		getColor(val, row) {
			if (this.colorType == 1) {
				if (val === '-' || parseFloat(val) == 0) return '';
				if (this.notReverse) {
					if (parseFloat(val) < 0) return this.downColor;
					if (parseFloat(val) > 0) return this.upColor;
				} else {
					if (parseFloat(val) < 0) return this.upColor;
					if (parseFloat(val) > 0) return this.downColor;
				}
			} else {
				if (val === '-' || parseFloat(val) == 0) return '';
				if (this.notReverse) {
					if (parseFloat(val) > 0) return this.downColor;
					if (parseFloat(val) < 0) return this.upColor;
				} else {
					if (parseFloat(val) > 0) return this.upColor;
					if (parseFloat(val) < 0) return this.downColor;
				}
			}
		},
		// 对比设置颜色：与昨天值相比
		getColorByCompareYest(row, item) {
			if (!item.compareYestKey) return '';           // 检验昨日值字段是否存在
			const today = row[item.key];
			const yest = row[item.compareYestKey];
			const num = today - yest;
			if (num == 0) return '';
			return num > 0 ? this.upColor : this.downColor;
		},
		// 设置table项的值，并处理未返回值时以'-'占位
		getValue(val) {
			if (!val && val != 0) return '-';
			else return val
		},
		// 设置每一列项的宽度
		setWidth() {
			const width = this.title.length > 2 ? 120 : 80;
			if (this.tablecolumn.length === 1) return null;
			else return width;
		},
		// 获取序号
		getNo(no) {
			if (this.showTotal) return no == 0 ? '' : no;
			else return no + 1
		},
		// 点击下钻操作, item: scope.row, key: 省份/地市/区县/机构列时为'name' 其他列项为列的item
		xiazuan(item, key) {
			// 如果这一行全为0则不能点击下钻
			const arrXz = [];
			this.tablecolumn.forEach(i => {
				arrXz.push(item[i.key]);
			});
			if (arrXz.some(i => { return i !== 0 })) {
				if (!this.filterDrillDown(item.name)) return;   // 特殊名称不可下钻
				if (key === 'name') {                           // 省份/地市/区县/机构列下钻
					if (!this.isDrillDown) return;              // 是否可再下钻标识，处理机构层级
					this.$emit('drilldown', {
						item: item,
						key: key
					})
				} else {                                        // 其他列下钻
					if (key.isDrillDown && item[key.key] != 0) {
						this.$emit('drilldown', {
							item: item,
							key: key.key
						})
					}
				}
			} else {
				if (this.xiazuanName == 'dqwxc') {
					this.$emit('drilldown', {
						item: item,
						key: key
					})
				}else{
					this.$emit('drilldown', {
						item: item,
						key: key
					})
				}
			}
		},
		// 依据sort配置项处理排序数据（初始化获取第一项排序的列）
		sortByData(column) {
			this.sortConfig = column;
			if (column instanceof Object) {
				let key = column.prop;
				if(key == 'blongName'){
					key = 'countyCode';
				};
				let orderBy = column.order;
				let filterColumn = this.list.filter(e => e.nameCode == 'total');   // 总计所在行数组
				let newTableData = this.list.filter(e => e.nameCode != 'total');   // 除总计外其他行数组
				let arr_list = newTableData.filter(z => z[key] == '-');            // 过滤出数据不为'-'的项数组
				let arr_list1 = newTableData.filter(z => z[key] != '-');           // 过滤出数据不为'-'的项数组
				if (orderBy == 'ascending') {
					arr_list1.sort((a, b) => {
						return (Number(b[key]) - Number(a[key]));
					})
					this.list = [...filterColumn, ...arr_list1, ...arr_list];
				} else if (orderBy == 'descending') {
					arr_list1.sort((a, b) => {
						return (Number(a[key]) - Number(b[key]));
					});
					this.list = [...filterColumn, ...arr_list1, ...arr_list];
				} else {
					this.list = this.list_copy;                                    // 接口初始返回的原数组
				}
			}
		},
		// 截取字符串最后两位
		sliceLastTwoStr(str) {
			return str ? str.slice(-2) : '00';
		},
		// 初始化默认操作方法
		initDefault() {
			document.documentElement.scrollIntoView();
			// 趋势图数据
			let trendList1 = JSON.parse(JSON.stringify(this.trendList));    // 今日趋势图(今日)接口返回数据
			let trendList3 = JSON.parse(JSON.stringify(this.yesTrendList));  // 今日趋势图(昨日)接口返回数据
			let dataTimeList = [],              // 趋势图：横轴坐标数据数组
				todayTrendValList = [],         // 趋势图-今日时间点：y轴数据数组
				yesTrendValList = [];           // 趋势图-昨日时间点：y轴数据数组
			if(this.isNotNullArray(trendList1)){
				trendList1.forEach((item) => {
					dataTimeList.push(this.sliceLastTwoStr(item.dataTime) + ':00');
					todayTrendValList.push(!item.mailNum ? 0 : item.mailNum);
				});
			}
			if(this.isNotNullArray(trendList3)){
				trendList3.forEach((item) => {
					yesTrendValList.push(!item.mailNum ? 0 : item.mailNum);
				});
			}
			let trendList2 = JSON.parse(JSON.stringify(this.historyList));  // 历史趋势图接口返回数据
			let hisDate = [], hisOverTime = [];
			if(this.isNotNullArray(trendList2)){
				trendList2.forEach((item) => {
					hisDate.push(item.dataTime.substring(5, 10));
					hisOverTime.push(!item.mailNum ? 0 : item.mailNum);
				});
			}
			// table列表数据
			let list = JSON.parse(JSON.stringify(this.list));
			// 依据nameCode升序排列
			let newList = list.sort((i, n) => {
				return Number(i.nameCode) - Number(n.nameCode);
			});
			newList =  this.sortSpecialInList(newList);
			this.sortByData(this.sortConfig);
			const arr = newList.filter(e => e.name !== '总计' && e.name !== '合计'); // 过滤掉合计行
			const xData = arr.map(i => i.name);                     // 趋势图横坐标数组
			const valueData = arr.map(i => i.value);                // y轴数组值: 今日实时量
			const valueData2 = arr.map(i => i.weight);
			if (valueData2.some(i => { return i !== undefined })) {
				this.initEcharts3(xData, valueData, valueData2);
			} else {
				if (this.choiceTypeName == '今日趋势图' || this.choiceTypeName == '历史趋势图'){
					if (this.choiceTypeName == '今日趋势图') {
						this.initEcharts4(dataTimeList, todayTrendValList, yesTrendValList);
					}else if (this.choiceTypeName == '历史趋势图') {
						this.initEcharts2(hisDate, hisOverTime);
					}
				}else{
					this.initEcharts2(xData, valueData);
				}
			}
		},
		// 历史趋势图配置(单折线)
		initEcharts2(xData, valueData) {
			let mychart2 = echarts.init(document.getElementById(this.idName));
			mychart2.clear();
			const _this = this;
			let option2 = {
				legend: {
					data: ['历史'],
					selectedMode: false,
					right: '10'
				},
				title: {
					text: _this.echartName + '(' + _this.echartLevelName + ')',
					textStyle: {
						color: 'black',
						fontSize: '13'
					}
				},
				color: ['#0199FF'],
				tooltip: {
					confine: true,
					trigger: 'axis',
					axisPointer: {                   // 坐标轴指示器，坐标轴触发有效
						type: this.choiceTypeName == '历史趋势图' ? 'line' : 'shadow' // 默认为直线，可选为：'line' | 'shadow'
					},
					formatter: function (params) {
						var result = ''
						var html = `<span style="display:inline-block;margin-right:5px;border-radius:10px;width:10px;height:10px;background-color:#0199FF;"></span>`;
						params.forEach(function (item) {
							_this.xiazuanName == 'clzxzjyjyx' ? result += item.axisValue + "</br>" + html + '在局邮件逾限量:' + item.data : result += item.axisValue + "</br>" + html + _this.echartName + ':' + item.data

						})
						return result
					},
					confine: true,
				},
				grid: {
					top: '15%',
					left: '3%',
					right: '4%',
					bottom: '15%',
					containLabel: true
				},
				xAxis: [{
					type: 'category',
					nameGap: 30,
					data: xData,
					axisLine: {
						lineStyle: {
							color: '#90979c'
						}
					},
					splitLine: {
						show: false
					},
					axisTick: {
						show: false
					},
					splitArea: {
						show: false
					},
					axisLabel: {
						interval: 0,
						rotate: 40,
						color: '#000000',
						formatter: (val) => {
							if (val && val.length > 6 && this.choiceTypeName != '历史趋势图') return val.substring(0, 6) + '...'
							else return val
						}
					}
				}],
				yAxis: [{
					type: 'value',
					max: _this.valueMax,
					axisLine: {
						show: true
					},
					axisTick: {
						show: true
					},
					axisLabel: {
						formatter: (val) => {
							if (Number(val) >= 10000) return (Number(val) / 10000).toFixed(0) + '万'
							else return val
						}
					}
				}],
				dataZoom: [
					{
						show: true,
						type: "slider",                           // 类型
						height: 30,
						xAxisIndex: [0],
						bottom: 10,
						startValue: (this.xiazuanName == 'clzxzjyjyx' || this.xiazuanName == 'dxsl' || this.xiazuanName == 'wrj' || this.xiazuanName == 'yxsl' || this.xiazuanName == 'yfsl' || this.xiazuanName == 'dqwxc') ? xData.length - 10 : 0,
						endValue: (this.xiazuanName == 'clzxzjyjyx' || this.xiazuanName == 'dxsl' || this.xiazuanName == 'wrj' || this.xiazuanName == 'yxsl' || this.xiazuanName == 'yfsl' || this.xiazuanName == 'dqwxc') ? 29 : (valueData.length > 6 ? 6 : valueData.length - 1),
						handleStyle: {                            // 滚动条手柄的样式
							color: "#40bcf9",
							borderColor: "#1fb2fb"
						},
						backgroundColor: "#e2f3ff",               // 背景
						dataBackground: {                         // 数据背景
							lineStyle: {
								color: "#000000"
							},
							areaStyle: {
								color: "#d4d9dd"
							}
						},
						fillerColor: "rgba(31,178,251,0.2)",      // 被start和end遮住的背景
					}, 
					{
						"type": "inside",
						"show": true,
						"height": 15,
						"start": 1,
						"end": 0
					}
				],
				series: [{
					type: _this.choiceTypeName == '历史趋势图' ? 'line' : 'bar',
					barWidth: 30,
					barGap: 20,
					color: '#0199FF',
					data: valueData,
					label: _this.choiceTypeName == '历史趋势图' ? {} : {
						normal: {
							show: 'true',
							position: 'inside',
							rotate: 45,
							fontSize: 10,
							color: "#FFFFFF",
							textBorderColor: '#0199FF',
							textBorderWidth: '3'
						}
					},
				}],
			}
			mychart2.setOption(option2, true);
		},
		// 双Y柱状图配置
		initEcharts3(xData, valueData, valueData2) {
			const _this = this;
			let mychart2 = echarts.init(document.getElementById(this.idName));
			let option2 = {
				legend: {
					data: ['总包数(袋/件)', '带运重量(吨)'],
					selectedMode: false
				},
				title: {
					"text": _this.echartName,
					left: '0%',
					textStyle: {
						color: 'black',
						fontSize: '13'
					}
				},
				tooltip: {
					trigger: 'axis'
				},
				grid: {
					top: '15%',
					left: '4%',
					right: '4%',
					bottom: '15%',
					containLabel: true
				},
				xAxis: [{
					type: 'category',
					nameGap: 30,
					data: xData,
					axisLine: {
						lineStyle: {
							color: '#90979c'
						}
					},
					splitLine: {
						show: false
					},
					axisTick: {
						show: false
					},
					splitArea: {
						show: false
					},
					axisLabel: {
						interval: 0,
						rotate: 40,
						color: '#000000',
						formatter: (val) => {
							if (val.length > 6) return val.substring(0, 6) + '...'
							else return val
						}
					}
				}],
				yAxis: [
					{
						type: 'value',
						name: '总包数(袋/件)',
						nameTextStyle: {
							fontSize: 10
						},
						axisLine: {
							lineStyle: {
								color: '#000',
							}
						},
						splitLine: {
							show: true
						},
						axisTick: {
							show: true
						},
						splitArea: {
							show: false
						},
						axisLabel: {
							formatter: (val) => {
								if (Number(val) >= 10000) return (Number(val) / 10000).toFixed(0) + '万'
								else return val
							}
						}
					},
					{
						name: "带运重量(吨)",
						type: "value",
						nameTextStyle: {
							fontSize: 10
						},
						axisLine: {
							lineStyle: {
								color: '#000',
							}
						},
						splitLine: {
							show: false
						},
						axisTick: {
							show: false
						},
						splitArea: {
							show: false
						},
						min: 0,
						max: Math.ceil(Math.max.apply(Math, valueData2)),
						axisLabel: {
							formatter: (val) => {
								console.log(Math.max.apply(Math, valueData2))
								console.log(val)
								if (val == 0) return 0
								else return Math.ceil(val)
							}
						},
					}
				],
				dataZoom: [
					{
						show: true,
						type: "slider",                           // 类型
						height: 30,
						xAxisIndex: [0],
						bottom: 10,
						startValue: 0,
						endValue: valueData.length > 5 ? 5 : valueData.length - 1,
						maxValueSpan: 5,
						mixValueSpan: 5,
						handleStyle: {                            // 滚动条手柄的样式
							color: "#40bcf9",
							borderColor: "#1fb2fb"
						},
						backgroundColor: "#e2f3ff",               // 背景
						dataBackground: {                         // 数据背景
							lineStyle: {
								color: "#000000"
							},
							areaStyle: {
								color: "#d4d9dd"
							}
						},
						fillerColor: "rgba(31,178,251,0.2)",      // 被start和end遮住的背景
					}, 
					{
						"type": "inside",
						"show": true,
						"height": 15,
						"start": 1,
						"end": 0
					}
				],
				series: [
					{
						type: 'bar',
						name: '总包数(袋/件)',
						data: valueData,
						barWidth: 15,
						itemStyle: {
							color: "#0199FF"
						},
						yAxisIndex: 0
					}, 
					{
						type: 'bar',
						name: "带运重量(吨)",
						data: valueData2,
						barWidth: 15,
						itemStyle: {
							color: "#FFE482",
						},
						yAxisIndex: 1
					}
				]
			}
			mychart2.setOption(option2, true);
		},
		// 今日(包含：今日-valueData、历史-valueData2时间点)趋势图配置(双折线)
		initEcharts4(xData, valueData, valueData2) {
			const _this = this;
			let mychart2 = echarts.init(document.getElementById(this.idName));
			mychart2.clear();
			let option2 = {
				legend: {
					data: ['今日', '昨日'],
					// selectedMode: false,       // 控制图例点击是否展示对应的折线图展示、隐藏
					right: '10'
				},
				title: {
					text: _this.echartName + '(' + _this.echartLevelName + ')',
					left: '0%',
					textStyle: {
						color: 'black',
						fontSize: '13'
					}
				},
				tooltip: {
					trigger: 'axis'
				},
				grid: {
					top: '15%',
					left: '4%',
					right: '4%',
					bottom: '15%',
					containLabel: true
				},
				xAxis: [{
					type: 'category',
					nameGap: 30,
					data: xData,
					axisLine: {
						lineStyle: {
							color: '#90979c'
						}
					},
					splitLine: {
						show: false
					},
					axisTick: {
						show: false
					},
					splitArea: {
						show: false
					},
					axisLabel: {
						interval: 0,
						rotate: 40,
						color: '#000000',
						formatter: (val) => {
							if (val && val.length > 6) return val.substring(0, 6) + '...'
							else return val
						}
					}
				}],
				yAxis: [{
					type: 'value',
					nameTextStyle: {
						fontSize: 10
					},
					axisLine: {
						lineStyle: {
							color: '#000000',
						}
					},
					splitLine: {
						show: true
					},
					axisTick: {
						show: true
					},
					splitArea: {
						show: false
					},
					axisLabel: {
						formatter: (val) => {
							if (Number(val) >= 10000) return (Number(val) / 10000).toFixed(0) + '万'
							else return val
						}
					}
				},],
				dataZoom: [{
					show: true,
					type: "slider",                           // 类型
					height: 30,
					xAxisIndex: [0],
					bottom: 10,
					startValue: xData.length - 10,
					endValue: valueData.length - 1,
					handleStyle: {                            // 滚动条手柄的样式
						color: "#40bcf9",
						borderColor: "#1fb2fb"
					},
					backgroundColor: "#e2f3ff",               // 背景
					dataBackground: {                         // 数据背景
						lineStyle: {
							color: "#000000"
						},
						areaStyle: {
							color: "#d4d9dd"
						}
					},
					fillerColor: "rgba(31,178,251,0.2)",      // 被start和end遮住的背景
				}],
				series: [
					{
						type: 'line',
						name: '今日',
						data: valueData,
						barWidth: 15,
						itemStyle: {
							color: "#0199FF"
						},
					}, 
					{
						type: 'line',
						name: '昨日',
						data: valueData2,
						barWidth: 15,
						itemStyle: {
							color: "#EF7C25",
						},
					}
				]
			}
			mychart2.setOption(option2, true);
		},
		filterHandler(value, row, column) {
			const property = column['property'];
			return row[property] === value;
		},
		// 判断是否为非空数组
		isNotNullArray(arr){
			if(arr && arr.length > 0 && Array.isArray(arr)){
				return true;
			}else{
				return false;
			}
		},
		// 判定是否存在特殊名字
		filterDrillDown(name) {
			if (this.specialName.indexOf(name) < 0) return true;  // 不存在
			else return false;                                    // 存在
		},
		// 对特殊名称进行排序，将特殊名称(如其他)排到数组最后
		sortSpecialInList(arr) {
			if (!Array.isArray(arr)) return [];
			const specialList = [];                               // 特殊名称项数组
			const normalList = arr.filter((item) => {
				if (item.name == '总计' || item.name == '合计') return true;
				if (!this.filterDrillDown(item.name)) {
					specialList.push(item);                        // 除了总计、合计之外的其他特殊名称
					return false;
				} else {
					return true;
				}
			})
			return [...normalList, ...specialList];
		}
	},
	template: 
		`<div>
			<div class="isShowBoxDiv">
				<div v-show="isShowLine" class="isShowLineDiv">
					<div :id="idName" class="isShowLineIdName"></div>
				</div>
				<div v-show="isShowBox && title == '区县'">
				<div class="isShowBoxRadio">
					<el-radio-group v-model="radio" @change="radioChange" size="small" >
						<el-radio label="1" >地市-区县-机构</el-radio>
						<el-radio label="2" >地市-机构</el-radio>
					</el-radio-group>
				</div>
			</div>
			<div v-show="isShowNote" class="isShowNoteDiv">备注：点击机构名称可查看机构趋势图</div>
			<div class="elTableDiv">
				<el-table
					:data="sortSpecialInList(list)" stripe
					:header-cell-style="{background:'#0199FF',color:'#FFF', height: '10px !important', 'text-align': 'center'}"
					:row-style="{height:'30px'}"
					:default-sort="defaultSort"
					:max-height="tableHeight"
					@sort-change='sortByData'
					:filter-method="filterHandler"
					style="width: 100%"
				>
					<el-table-column label="序号" align="center" fixed width="50">
						<template slot-scope="scope">
							{{ getNo(scope.$index) }}
						</template>
					</el-table-column>
					<!--省、地市、区县、机构列-->
					<el-table-column prop="nameCode" :label="title"
						fixed sortable="custom" :width="setWidth()" align="center"
					>
						<template slot-scope="scope">
							<span :style="[isDrillDown && filterDrillDown(scope.row.name) ? style1 : style2 ]"
								@click="xiazuan(scope.row, 'name')">{{scope.row.name}}</span>
						</template>
					</el-table-column>
					<template v-for="item in tablecolumn">
						<!--单层表头-->
						<el-table-column v-if="!item.children"
							:key="item.key" :prop="item.key" :label="item.label"
							:sortable="item.sortable ? 'custom' : false"
							:width="item.width" :align="!item.align ? 'center' : item.align"
						>
							<template slot-scope="scope">
								<!--如果是率--> 
								<span v-if="item.isRate" :style="{color: !item.filter ? getColor(scope.row[item.key], scope.row) : item.filter(scope.row[item.key])}">
									{{getValue(scope.row[item.key])}}
								</span>
								<!--如果需要对比昨日值，显示不同颜色--> 
								<span v-if="item.isCompareYest :style="{color: getColorByCompareYest(scope.row,item)}">
									{{ getValue(scope.row[item.key]) }}
								</span>
								<!--其他--> 
								<span v-else @click="xiazuan(scope.row, item)" 
									:style="[
										item.isDrillDown && scope.row[item.key] != 0 ? style1 : style2,
										filterDrillDown(scope.row.name) && scope.row[item.key] != 0 && item.independence ? style1 : style2
									]"
								>
									{{getValue(scope.row[item.key])}}
								</span>
							</template>
						</el-table-column>
						<!--双层表头-->
						<el-table-column
							v-else
							:key="item.key"
							:prop="item.key"
							:label="item.label"
							:align="!item.align ? 'center' : item.align" >
							<el-table-column
								v-for="item in item.children" 
								:key="item.key" 
								:label="item.label"
								:prop="item.key" 
								:sortable="item.sortable ? 'custom' : false"
								:width="item.width"
								:align="!item.align ? 'center' : item.align">
								<template slot-scope="scope">
									<!--如果是率--> 
									<span v-if="item.isRate" :style="{color: !item.filter ? getColor(scope.row[item.key]) : item.filter(scope.row[item.key])}">
										{{getValue(scope.row[item.key])}}
									</span>
									<!--如果需要对比昨日值，显示不同颜色--> 
									<span v-else-if="item.isCompareYest"  :style="{color: getColorByCompareYest(scope.row,item)}">
										{{ getValue(scope.row[item.key]) }}
									</span>
									<!--其他--> 
									<span v-else @click="xiazuan(scope.row, item)" 
										:style="[item.isDrillDown && scope.row[item.key] != 0 ? style1 : style2 ]"
									>
										{{getValue(scope.row[item.key])}}
									</span>
								</template>
							</el-table-column>
						</el-table-column>
					</template>
				</el-table>
			</div>
		</div>
	</div>`
});