// 红图表格组件
/**
 * 表
 * isNo: 是否显示序号列
 * redBy: 是否红图模式[min,max]
 * notReverse: 红绿色显示逻辑是否反转
 * specialName: 不参与排序的特殊行
 * 列
 * subByZero: true数字显示红绿色根据0分割为2段 绿-红
 * subByTarget: key数字显示红绿色根据字段分割为2段 绿-红
 * subByKey: 数字显示红绿色根据0和字段分割为3段 绿-黑-红
 * subDown: 比给定值小的显示红色
 * subUp: 比给定值大的显示绿色
 * reverse: 单列的颜色设置是否反转，支持subByZero、subByTarget
 * isRate: 一般在表头显示%，isRate时单元格显示%
 * isNumber: 表示这一列是数字，需要粗体显示
 * align: 值靠左靠右
 * paddingRight: 值右边距，和align=right组合使用
 */
 Vue.component('redDrillDownTable', {
	data() {
		return {
			normalColor: '#333333',
			drillColor: '#3377FF',
			upColor: '#009900',
			downColor: '#FA2525',
			toastId: null,
			citys: []
		}
	},
	props: {
		defaultColor: {
			String,
			default: () => {
				return '';
			}
		},
		// table列-表头项
		tablecolumn: {
			Array,
			default: () => {
				return [{
					label: '封发量',
					key: 'value',
				}]
			}
		},
		// table列表高度
		tableHeight: {
			Number,
			default: () => {
				// 获取页面高度
				const h = document.documentElement.clientHeight || document.body.clientHeight
				// 减去上方区域
				return h - 30;
			}
		},
		// table列表数据
		list: {
			Array,
			default: () => {
				return [{
					name: '北京市',
					value: '36',
					zrtb: 0
				}]
			}
		},
		type: {
			String,
			default: 'isCity'
		},
		// 是否上拉加载更多
		isLoadMore: {
			Boolean,
			default: false
		},
		notReverse: {
			Boolean,
			default: true
		},
		subByZero: {
			Boolean,
			default: false
		},
		specialName: {
			Array,
			default: () => {
				return []
			}
		},
		// 是否红图模式
		redBy: {
			Object,
			default: null
		}
	},
	watch: {},
	// 计算属性
	computed: {
		rowLen: function() {   // table列表行长度
			return this.list ? this.list.length : 0;
		},
		colLen: function() {   // table列表列长度
			return this.tablecolumn ? this.tablecolumn.length : 0;
		},
	},
	methods: {
		// 设置列项的宽度,text: item.label
		setColumnWidth(text) {
			if (this.tablecolumn.length <= 3) return null;
			if (!text) {
				return 96;
			}
			return 96;
		},
		// 设置td项距右距离
		getPaddingRight(scope, item) {
			if (item.paddingRight) {
				if (item.paddingRight > 0) {
					return item.paddingRight + 'px';
				}
			}
			if (item.paddingRight < 0 || (!item.width && item.align == 'right')) {
				let width = (scope.column.realWidth - scope.column.label.length * 12) / 2;
				if (item.sortable) {
					width += 12;
				}
				if (width > 0) {
					return width + 'px';
				}
			}
			if (item.sortable && item.align == 'right') {
				return '24px';
			}
			return '0px';
		},
		// 设置列项排序图标
		getSortIcon(index) {
			if (index == 1) {
				return '../../../image/icon/sort_1.png';
			} else if (index == 2) {
				return '../../../image/icon/sort_2.png';
			} else {
				return '../../../image/icon/sort_3.png';
			}
		},
		// 设置table项的toast提示
		toggleToast(row, item) {
			let views = this.$refs.toast;
			let pop;
			if (views) {
				if (views.length > 1) {
					pop = views[1];
				} else if (views.length > 0) {
					pop = views[0];
				}
			}
			if (!pop) return;
			// 某个单元格需要点击吐丝提示增加的代码
			if (this.toastId) {
				clearTimeout(this.toastId);
			}
			if (pop.value) {
				pop.value = false;
			} else {
				pop.value = true;
				this.toastId = setTimeout(() => {
					pop.value = false;
					this.toastId = null;
				}, 3100);
			}
		},
		// 设置列头及行头的cell样式
		changeCellStyle({ row, column, rowIndex, columnIndex }) {
			if (this.redBy) {           // 红图模式
				if (columnIndex === 0) {
					return 'background:#0197FF; color:#ffffff; text-align:center;';
				} else if (this.redBy.max) {
					if (row[column.property] > this.redBy.max) {
						return 'text-align:right;padding-right:14px;background: #58DEB6;';
					} else if (row[column.property] < this.redBy.min) {
						return 'text-align:right;padding-right:14px;background: #FF6666;';
					} else {
						return 'text-align:right;padding-right:14px;background: #FFFFFF;';
					}
				} else if (row[column.property] && row[column.property].color) {
					return 'text-align:right;padding-right:14px;background: ' + row[column.property].color + ';';
				}
			}
			return null;
		},
		// 特殊名字过滤
		filterDrillDown(row, item) {
			if (this.specialName.indexOf(row.name) >= 0) {
				return false;
			}
			return true;
		},
		// table列-表头项过滤
		filterColumn(c) {
			return c.filter(function(item) {
				return item.chose == undefined || item.chose;
			});
		},
		// 设置td项的颜色
		getColor(row, item) {
			// console.log('getColor--row值: '+JSON.stringify(row));
			// console.log('getColor--item值: '+JSON.stringify(item));
			// console.log('getRow--itemKey值: '+JSON.stringify(row[item.key]));
			if (row[item.key] && row[item.key].flag && row[item.key].flag == '1') {
				return this.upColor;
			}else if (row[item.key].flag == '2'){
				return this.downColor;
			}
			// 红图模式，样式自定
			if (this.redBy) {                   
				return;
			}
			if (item.isDrillDown && this.filterDrillDown(row, item)) {
				if (!row.notDrill && row[item.key] != 0) {
					if (this.defaultColor) {
						// 如果设置有主色调颜色，下钻单元格问题颜色用主色调,否则用默认
						return this.defaultColor;
					}
					return this.drillColor;
				}
			}
			if (item.compareKey) {
				if (row[item.compareKey] != 0) {
					if (this.notReverse) {
						if (row[item.compareKey] > 0) return this.upColor;
						if (row[item.compareKey] < 0) return this.downColor;
					} else {
						if (row[item.compareKey] < 0) return this.upColor;
						if (row[item.compareKey] > 0) return this.downColor;
					}
				}
			}
			// 以0分为2段
			if (item.subByZero) {
				let val = row[item.key];
				if (val != '-' && parseFloat(val) != 0) {
					if (this.notReverse && !item.reverse) {
						if (parseFloat(val) < 0) return this.downColor;
						if (parseFloat(val) > 0) return this.upColor;
					} else {
						if (parseFloat(val) < 0) return this.upColor;
						if (parseFloat(val) > 0) return this.downColor;
					}
				}
			}
			// 以key分为2段
			if (item.subByTarget) {
				let val = row[item.key];
				let sub = row[item.subByTarget];
				if (val != '-' && parseFloat(val) != 0) {
					if (this.notReverse && !item.reverse) {
						if (parseFloat(val) < sub) return this.downColor;
						if (parseFloat(val) > sub) return this.upColor;
					} else {
						if (parseFloat(val) < sub) return this.upColor;
						if (parseFloat(val) > sub) return this.downColor;
					}
				}
			}
			// 以0和key分为3段
			if (item.subByKey) {
				let sub = row[item.subByKey];
				let val = row[item.key];
				if (val != '-' && parseFloat(val) != 0) {
					if (val <= 0) {
						return this.downColor;
					} else if (val > sub) {
						return this.upColor;
					} else {
						return this.normalColor;
					}
				}
			}
			if (item.subDown || parseFloat(item.subDown) === 0) {
				let val = row[item.key];
				let sub = item.subDown;
				if (val != '-' && parseFloat(val) != 0) {
					if (this.notReverse) {
						if (parseFloat(val) < sub) return this.downColor;
					} else {
						if (parseFloat(val) < sub) return this.upColor;
					}
				}
			}
			if (item.subUp || parseFloat(item.subUp) === 0) {
				let val = row[item.key];
				let sub = item.subUp;
				if (val != '-' && parseFloat(val) != 0) {
					if (this.notReverse) {
						if (parseFloat(val) > sub) return this.upColor;
					} else {
						if (parseFloat(val) > sub) return this.downColor;
					}
				}
			}
			return this.normalColor;
		},
		// table列表：td项的值，以行为单位，取某一列的值定位到具体的元素块的值
		getValue(val, compareKey, isRate, is10Thousand) {
			// console.log('getValue值: '+JSON.stringify(val));
			// flag: 今日较昨日变换状态 "1": 正-绿, "0": 等于 原色，" 2"：负-红
			if(val.value){
				if(val.flag){  
					return val.flag == '1' ? val.value + ' ↑' : val.value + ' ↓'; 
				}else {                             
					return val.value;                
				}
			}else{
				return val ? val : '-';               // 行头名称或者该项数据为空
			}


			if (val && val.color) {                    // 重点区域提速-红图使用
				val = val.value;
			}
			let res;
			if (val === undefined || val === '' || val == null) {
				res = '-'
			} else if (compareKey && compareKey < 0) {
				res = "-" + val;
			} else {
				res = val;
			}
			if (isRate && res != '-') {
				res = res + "%";
			} else if (is10Thousand && res != '-') {
				res = (res / 10000).toFixed(2);       // 列以万为单位
			}
			return res;
		},
		// 列下钻
		headDrillDown(col) {
			// 过滤直辖市下钻
			if(col.key.substr(2, 4) + '' !== '0000') {
				if(col.key == "999999") {
					this.$message({
						message: '总计不支持下钻！',
						duration:'1000'
					}, 1000);
				} else {
					this.$message({
						message: '寄达支持下钻到地市！',
						duration:'1000'
					}, 1000);
				}
				return false
			}
			this.$emit('head-drill-down', { col })
        },
		// 行下钻： row：行信息值，item：列信息值，index：下钻行下标
		xiazuan(row, item, index) {
			// console.log('xiazuan--row值: '+JSON.stringify(row));
			// console.log('xiazuan--item值: '+JSON.stringify(item));
			if(item.key !== "name") {    // 非行头名称下钻: 获取详情
				if(row.code == '999999' || item.key == '999999'){
					return;
				}
				let itemObj = row[item.key];      // 点击项的详情信息对象值
				this.$emit('drilldowndetail', {itemObj});
				return;
			}
			if(row.code.substr(4, 6) + '' !== '00') { // 截取机构码最后两位，(前两位：省份、中间两位：地市，后两位：区县)
				if(row.code == "999999") {
					this.$message({
						duration:'1000',
						message: '总计不支持下钻！',
					}, 1000);
				} else {
					this.$message({
						duration:'1000',
						message: '原寄支持下钻到区县！',
					}, 1000);
				}
				return;
			}
			this.$emit('drilldown', {row});
		},
		// table排序功能
		changeTableSort({ column, prop, order }) {
			if (column.sortable !== 'custom') {
				return;
			}
			let fieldName = prop;
			let sortingType = order;
			let list = this.list;
			let orderList = [];
			let freeList = [];
			list.map(it => this.specialName.indexOf(it.name) >= 0 ? freeList.push(it) : orderList.push(it));
			if (sortingType == 'descending') {
				list = orderList.sort((a, b) => a[fieldName] - b[fieldName]);
				freeList.push.apply(freeList, orderList);
				this.list = freeList;
			} else if (sortingType == 'ascending') {
				orderList = orderList.sort((a, b) => b[fieldName] - a[fieldName]);
				freeList.push.apply(freeList, orderList);
				this.list = freeList;
			} else {
				orderList = orderList.sort((a, b) => a.nameCode > b.nameCode ? 1 : -1);
				freeList.push.apply(freeList, orderList);
				this.list = freeList;
			}
			this.$emit('sortList', this.list);
			this.$emit('sort-list', this.list);
		},
		// table排序处理方法
		sortMethod(a, b, key, compareKey) {
			let l = a[key];
			let r = b[key];
			if (l == undefined || l == null || l == '') {
				l = -100000000;
			} else {
				if (a[compareKey] < 0) {
					l *= -1;
				}
			}
			if (r == undefined || r == null || r == '') {
				r = -100000000;
			} else {
				if (b[compareKey] < 0) {
					r *= -1;
				}
			}
			return r - l;
		},
		// 注册并设置加载更多监听功能
		registerLoadMoreListener() {
			const selectWrap = document.querySelector('.el-table__body-wrapper');
			selectWrap.addEventListener('scroll', () => {
				const scrollDistance = selectWrap.scrollHeight - selectWrap.scrollTop - selectWrap.clientHeight;
				// console.log('scrollDistance值: '+scrollDistance);
				// 同时满足以下情况，加载下一页
				// 1.页面滑动到底部，即scrollDistance = 0
				// 2.页面有滑动的情况，即selectWrap.scrollHeight > selectWrap.clientHeight
				if (scrollDistance <= 2 && selectWrap.scrollHeight > selectWrap.clientHeight) {
					this.$emit('load-more');         // 加载更多
				}
			})
		},
	},
	mounted() {
		if (this.isLoadMore) {              // 加载更多
			this.registerLoadMoreListener();
		}
	},
	// el-table表格 以:data绑定行元素数组
	template: 
		`<div class="redTableTemp">
			<el-table :data="list"
				ref="tableActive" stripe border fit
				header-cell-class-name="blue-table-header"
				row-class-name="blue-table-row"
				:header-cell-style="{background:defaultColor ? defaultColor : '#0199FF',color:'#FFFFFF', height: '30px', 'text-align': 'right', fontSize: '12px', fontWeight: 'normal'}"
				:row-style="{height:'30px',fontSize: '12px'}"
				:cell-style="changeCellStyle" :height="tableHeight"
				@sort-change="changeTableSort"
			>
				<el-table-column
					v-for="item in filterColumn(tablecolumn)"
					:key="item.key"
					:prop="item.key" :sortable="item.sortable"
					:fixed="item.fixed ? true : false"
					:sort-method="(a,b) => sortMethod(a,b,item.key,item.compareYestKey)"	
					:width="item.width ? item.width : setColumnWidth(item.label)"
					:align="!item.align ? 'right' : item.align"
				>
					<template slot="header" slot-scope="scope">
						<span @click="headDrillDown(item)">
							{{ item.label }}
						</span>
					</template>
					<template slot-scope="scope">
						<div v-if="scope.row.toast && item.toast" >
							<el-popover ref="toast" trigger="manual" placement="bottom-start"
								:content="scope.row.toast"
							>
								<span slot="reference" @click="toggleToast(scope.row,item)" 
									:style="{color: getColor(scope.row,item),fontWeight:item.isNumber ? 600 : 'normal',paddingRight: getPaddingRight(scope, item)}" >
									{{ getValue(scope.row[item.key],scope.row[item.compareYestKey],item.isRate,item.is10Thousand) }}
								</span>
							</el-popover>
						</div>
						<div v-else-if="item.isProgress" 
							:class="scope.row[item.key] > 0 ? 'progressBox positive' : 'progressBox negative'">
							<el-progress
								:percentage="scope.row[item.key + 'Progress']"
								:color="scope.row[item.key] > 0 ? '#00C482' : '#F74627'"
								:stroke-width="21" :show-text="false"
							>
							</el-progress>
							<p :style="{color: getColor(scope.row,item),fontWeight:item.isNumber ? 600 : 'normal',paddingRight: getPaddingRight(scope, item)}" >
								{{ getValue(scope.row[item.key],scope.row[item.compareYestKey],item.isRate,item.is10Thousand) }}
							</p>
						</div>
						<div v-else>
							<img v-if="item.rank && scope.row[item.key] <= 3" 
								style="width:0.16rem; height:0.16rem;" 
								:src="getSortIcon(scope.row[item.key])" >    
							<span v-else 
								@click="xiazuan(scope.row, item,scope.$index)" 
								:style="{color: getColor(scope.row,item),fontWeight:item.isNumber ? 600 : 'normal',paddingRight: getPaddingRight(scope, item)}" >
								{{ getValue(scope.row[item.key],scope.row[item.compareYestKey],item.isRate,item.is10Thousand) }}
							</span>
						</div>
					</template>
				</el-table-column>
			</el-table>
		</div>`
});


  