/* 获取渲染折线图数据
*  id: 绘制组件id名，xAxisData：横坐标轴数据数组，yAxisData：y坐标轴数据数组
* */
function getDbLineEchart(id, xAxisData, yAxisData, legendP) {
    let series = [];                                          // 折线图属性设置配置项数组
    let legend = legendP && legendP.length > 0 ? legendP :['进口量'];   // 图例
    let setColorArr = ['#0197FF','#009900'];                           // 折线图颜色属性色系数组
    legend.forEach((item, index) => {
        let setting = {};
        setting.data = yAxisData[index];                      // 设置y轴值
        setting.color = setColorArr[index];                   // 设置折线色值
        series.push(setting);
    });
    dbLineEchart(id, xAxisData, series, legend, [0,10], [yAxisData[0].length, 5]);
}
/* 绘制双折线图组件: 
* id: 绘制组件id名，xData：横坐标轴数据数组，series：series设置数据数组，legend: 图例名数组
* legendSet: 设置图例的位置（非必传）
* zoomSet: 设置手柄的起始结束点（非必传）, 默认：null，存在时：[xData.length, limitLen] 
* */
function dbLineEchart(id, xData, series, legend, legendSetP, zoomSetP) {
    let lineEchart = echarts.init(document.getElementById(id));     // 获取绘制折线图的区域id
    lineEchart.clear();                                             // 先清除原绘制折线，再重新绘制填充，避免污染
    let legendSet = legendSetP ? legendSetP : [30,10];              // 设置图例的属性
    let zoomSet = dataZoomStartEnd(zoomSetP);                       // 设置手柄的起始结束点
    let seriesArr = [];                                             // 设置折线图属性配置项数组
    series.forEach((item, idx) => {
        let setting = {
            type: 'line',
            name: legend[idx],                     // 图例名称
            data: item.data,
            symbolSize: 6,
            symbol: 'circle',                      // 拐点：emptyCircle：空心，circle: 实心
            itemStyle: {
                normal: {
                    color: item.color ? item.color : '#0197FF',
                    borderColor: '#ffffff',
                    barBorderRadius: 1,
                    borderWidth: 2
                }
            },
            lineStyle: {
                normal: {
                    color: item.color ? item.color : '#0197FF',
                    width: 2
                }
            },
			areaStyle: {
				normal: {
					color: idx == 1 ? new echarts.graphic.LinearGradient(0, 0, 0, 1, [{
                        offset: 0, color: 'rgba(0, 153, 0, 0.1)'   // 0% 处的颜色
                        }, {
                        offset: 1, color: '#FFFFFF' // 100% 处的颜色
                        }]
					) : new echarts.graphic.LinearGradient(0, 0, 0, 1, [{
                        offset: 0, color: 'rgba(1, 151, 255, 0.1)' // 0% 处的颜色
                        }, {
                        offset: 1, color: '#FFFFFF' // 100% 处的颜色
                        }]
                    ),                            // 区域面积颜色渐变
				},
			},
            // smooth: true,                      // 折线图是否平滑绘制
        }           
        seriesArr.push(setting);
    });
    let option = {
        tooltip: {
            trigger: 'axis',
            axisPointer: {
                type: 'line'
            }
        },
        legend: {
            data: legend,
            right: '4%',
            top: legendSet[0],               // 与外部容器之间的距离
            itemGap: legendSet[1],           // 每一项之间的距离
            // selectedMode: false,          // 控制图例点击是否展示对应的折线图展示、隐藏
            width: 240
        },
        grid: {
            top: '13%',                 // 网格线: 即折线图距顶位置
            left: '3%',
            right: '4%',
            bottom: '10%',
            containLabel: true
        },
        xAxis: [
            {
                type: 'category',
                data: xData,
                axisLine: {
                    lineStyle: {
                        color: '#90979c',
                    }
                },
                splitLine: {
                    show: false
                },
                axisTick: {
                    show: true
                },
                splitArea: {
                    show: false
                },
                axisLabel: {
                    interval: 0,
                    rotate: 40,
                }
            }
        ],
        yAxis: [
            {
                name: '',
                type: 'value',
                axisLine: { show: false },
				splitLine: {
					lineStyle: {
						type: 'dashed',        // 横向网格线：虚线
					},
				},
                axisTick: {
                    show: false,
                },
                axisLabel: {
                    margin: 2,
                    formatter: function (value) {
                        if (value >= 10000 && value < 100000000) {
                            value = value / 10000 + '万'
                        } else if (value >= 100000000) {
                            value = value / 100000000 + '亿'
                        }
                        return value
                    }
                    // formatter: (val) => {
                    //     if (Number(val) >= 10000) return (Number(val) / 10000).toFixed(0) + '万'
                    //     else return val
                    // }
                }
            }
        ],
        dataZoom: [{
            show: true,
            type: "slider",                           // 类型
            height: 20,
            bottom: 8,
            startValue: zoomSet[0],
			endValue: zoomSet[1],
            handleStyle: {                            // 滚动条手柄的样式
                color: "#40bcf9",
                borderColor: "#1fb2fb"
            },
            backgroundColor: "#e2f3ff",               // 背景
            dataBackground: {                         // 数据背景
                lineStyle: {
                    color: "#000000"
                },
                areaStyle: {
                    color: "#d4d9dd"
                }
            },
            fillerColor: "rgba(31,178,251,0.2)",      // 被start和end遮住的背景
        }],
        series: seriesArr,
    }
    lineEchart.setOption(option);
}
// 获取手柄图例初始固定区间段
function dataZoomStartEnd(zoomSet){
    let curHour = dayjs().get('hour'), retHour, resData = [];
    if(zoomSet && zoomSet.length > 0){
        retHour = zoomSet[0] > zoomSet[1] ? zoomSet[0] - zoomSet[1] : 0;
        resData = [retHour, zoomSet[0]-1];
    }else{                      // 横坐标: 日期小时时间
        if(curHour<=5){
            retHour = 5;
        }else{
            retHour = curHour+1;
        }
        resData = [retHour-5, retHour];
    }
    return resData;
}
// 获取X轴区间段（x轴为空数据时）
function getXAxisBlankData(){
    var date = new Date();
    var currHour = date.getHours();
    let timeSoltList = [];
    if(currHour > 5){
        let timeSoltArray = [currHour-5, currHour-4, currHour-3, currHour-2, currHour-1];
        timeSoltArray.map((item) => {
            let timeSolt = '';
            if(item > 9){
                timeSolt = item + ':00';
            }else{
                timeSolt = '0' + item + ':00';
            }
            timeSoltList.push(timeSolt);
        })
    }else if(currHour == 0){
        let timeSolt = '00:00';
        timeSoltList.push(timeSolt);
    }else{
        for(var i=0; i<currHour; i++){
            let timeSolt = '0'+i + ':00';
            timeSoltList.push(timeSolt);
        }
    }
    return timeSoltList;
}
// 双折线图组件
Vue.component('dbechart-line', {
	data() { },
	props: {
		// id值：绘制元素的id值
        idName: {
            type: String,
            required: true
        },
		// 标题
        title: {
            type: String,
            required: true
        }
	},
	methods: {
		initDbLineEchart(xAxisData, yAxisData) {
            let xAxisBlankData = ['0', '0', '0', '0', '0'];  // 横坐标数据为空
            if(xAxisData.length == 0){
                xAxisBlankData = getXAxisBlankData();
            }
			let legend = ['今日处理量','昨日处理量'];          // 图例
			// 空数组时默认值处理：
			let xAxisList = xAxisData.length > 0 ? xAxisData : xAxisBlankData;
			let y1AxisList = yAxisData.y1.length > 0 ? yAxisData.y1 : [0, 0, 0, 0, 0];
            let y2AxisList = yAxisData.y2.length > 0 ? yAxisData.y2 : [0, 0, 0, 0, 0];
            let yAxisList = []; 
            yAxisList.push(y1AxisList);
            yAxisList.push(y2AxisList);
			getDbLineEchart(this.idName, xAxisList, yAxisList, legend);
		},	
	},
	mounted() {},
	// 渲染组件界面
	template: `<div :id="idName" class="echartBox"></div>`
});


  