// table表格组件(可下钻)
Vue.component('drilldown-table', {
	props: {
		// table列表的高度
		tableHeight: {
			String,
			default: () => {
				const h = document.documentElement.clientHeight || document.body.clientHeight; // 获取页面高度
				return h - 37;                                                                 // 减去上方区域
			}
		},
		// 是否展示总计功能：默认：true 展示总计或者集团(全国)
		showTotal: {
			Boolean,
			default: true
		},
		// table列表配置项--列表头
		tableColumn: {
			Array,
			default: () => {
				return []
			}
		},
		// table列表的data数据
		moduleList: {
			Array,
			default: () => {
				return []
			}
		},
		// 允许下钻的字段key值
		drillDownKeys: {
			Array,
			default: () => {
				return ['name']
			}
		},
		refName: {
			String,
			default: 'dialogTable'
		},
		// 需要过滤的名称
		filterName: {
			Array,
			default: () => {
				return []
			}
		},
		defaultSort: Object,
		onlyDrillName: {
			Array,
			default: () => {
				return []
			}
		},
		// 行中每项样式
		rowStyle: {
			type: Object || Function,
			default: () => {
				return {
					'font-size': '14px',
					'line-height': '23px',
					'padding': '7px 0'
				}
			}
		},
		// 行列头-项样式
		headStyle: {
			Object,
			default: () => {
				return {}
			}
		},
		// 可下钻-活跃项字体颜色
		activeFontColor: {
			String,
			default: 'blue'
		},
		// 是否上拉加载更多
		isLoadMore: {
			Boolean,
			default: false
		},
	},
	data() {
		return {
			dataList: [],           // table列表排序处理后的data数组数据
			sortList: [],           // table列表排序对象：{ key: item.key, sort: 0 }数组数据
			fixedLeft: false,       // 是否居左固定标识
		}
	},
	// 计算属性: 监听并跟随total值变更时，更新总计值
	computed: {
		totalValue() {
			return this.moduleList.find(i => i.nameCode === 'total');
		}
	},
	watch: {
		moduleList: {
			handler(newValue, oldValue) {
				// if (newValue == oldValue) return;               // 排序图标置空
				this.sortList.forEach(item => {
					const refs = this.$refs[item.key];
					refs.forEach(i => {
						i.style.color = '#FFFFFF'
					})
				});
				if (newValue.length == 0) {
					this.dataList = [];
					return
				}
				const sort = this.defaultSort;
				const total = newValue.find(i => i.nameCode === 'total');
				let data = this.showTotal ? newValue.filter(i => i.nameCode !== 'total') : JSON.parse(JSON.stringify(newValue));
				if (sort) {
					let newdata = sort.sort === 'up' ? data.sort((a, b) => a[sort.key] - b[sort.key]) : data.sort((a, b) => b[sort.key] - a[sort.key])
					if (this.showTotal && total) newdata.unshift(total);
					this.dataList = newdata;
				} else {
					if (this.showTotal && total) data.unshift(total);
					this.dataList = data;
				};
				this.$refs[this.refName].bodyWrapper.scrollTop = 0;
				this.$refs[this.refName].bodyWrapper.scrollLeft = 0;
			},
			immediate: false
		},
		tableColumn: {
			handler(newValue, oldValue) {
				this.sortList.forEach(item => {
					const refs = this.$refs[item.key];
					refs.forEach(i => {
						i.style.color = '#FFFFFF'
					})
				});
				this.getSortList(newValue);
				// 用于检测数组中的元素是否满足指定条件,如果有一个元素满足条件，则表达式返回true 
				this.fixedLeft = newValue.some(item => item.fixed === 'left');
			},
			immediate: true
		}
	},
	methods: {
		// 设置位置-table项展示内容的位置
		translateTextAlign(item) {
			const val = item.headAlign ? item.headAlign : item.align;   // headAlign: 顶部列表头项位置
			const obj = {
				left: 'flex-begin',
				center: 'center',
				right: 'flex-end;'
			};
			return val ? obj[val] : 'flex-end';
		},
		// 设置table列表行样式
		setRowStyle(align) {
			if (Object.prototype.toString.call(this.rowStyle) === '[object Function]') {  // 对象或者函数类型
				return this.rowStyle(align);
			} else {
				return this.rowStyle;
			}
		},
		// 设置序号
		getNo(no) {
			if (this.showTotal) return no == 0 ? '' : no;     // 存在总计时，总计行的序号为空
			else return no + 1;
		},
		// 设置颜色-table项展示内容的颜色，i：item列项信息，row：行信息
		getColor(i, row) {
			// if (row[i.key] == 0) return '';                // 数据为0, 颜色置为默认黑色
			if (i.key == 'onroadCars' || i.key == 'inFenceCars' || i.key == 'unsealCars' || i.key == 'sealedCars') {
				if (row.nameCode == 'total' || this.filterName.some(i => i === row.name) ||
					(this.onlyDrillName.length != 0 && !this.onlyDrillName.some(i => i === row.nameCode))) return '';
			}
			const rateColor = i.fontColor ? i.fontColor(row) : '';
			return this.drillDownKeys.indexOf(i.key) < 0 ? rateColor : this.activeFontColor;
		},
		// 空占位：当返回值为undefined,null,NaN时，此时数据展示用'-'占位
		nullBlank(val) {
			let res = val;
			if (val == undefined || val == null || val == NaN) {
				res = '-';
			}
			return res;
		},
		// table列表：td项的展示值
		getSpanValue(val, itemFilter) {
			// console.log('getSpanValue值: '+JSON.stringify(val));
			let res;
			if (itemFilter) {
				res = itemFilter(val);
			} else {
				res = this.nullBlank(val);
			}
			return res;
		},
		// 下钻功能：table表格项点击，i：item列项信息，row：行信息
		handleClick(i, row) {
			// 允许下钻的Keys的数组中未包含当前项，或nameCode = 'total'(即：集团/全国/总计/合计)时，不允许下钻
			if (this.drillDownKeys.indexOf(i.key) < 0 || this.filterName.some(i => i === row.name) || row.nameCode === 'total' ||
				(this.onlyDrillName.length != 0 && !this.onlyDrillName.some(i => i === row.nameCode))) return;
			// if (row[i.key] == 0) return;               // 当前点击项数据为0时，不允许下钻
			this.$emit('drilldown', {
				key: i.key,
				row: row
			})
		},
		// 获取排序列表数据
		getSortList(newValue) {
			let sortListNormal = [...newValue.filter(item => item.sort).map(item => {
				return {
					key: item.key,
					sort: 0
				}
			})]
			let childrenList = [...newValue.filter(item => item.children)]; // 二级表头排序配置
			let sortListChildren1 = [], sortListChildren2 = [];
			if (childrenList.length !== 0) {
				sortListChildren1 = [this.getSortListChildren(...childrenList[0])];
				sortListChildren2 = [this.getSortListChildren(...childrenList[1])];
				this.sortList = [...sortListNormal, ...sortListChildren1, ...sortListChildren2];
			} else {
				this.sortList = [...sortListNormal];
			}
		},
		// 获取排序列表的子列表数据
		getSortListChildren(childrenList) {
			childrenList.children.filter(item => item.sort).map(item => {
				return {
					key: item.key,
					sort: 0
				}
			});
			return childrenList;
		},
		// 获取当前key：特殊处理部分字段name的code取值,即常用的枚举类型：省，市，机构等存在名称和code值不一致的情况
		getNameToCodeCurkey(key) {
			let curkey = key;
			if (key == 'provName') {
				curkey = 'provCode';
			} else if (key == 'cityName') {
				curkey = 'cityCode';
			} else if (key == 'orgName') {
				curkey = 'orgCode';
			};
			return curkey;
		},
		// 设置排序的列头项上下指示箭头样式
		setSortArrowStyle(itemKey, fixed, colorList) {
			let index0 = 0, index1 = 1;
			if (this.fixedLeft && fixed != 'left') {
				index0 = 2;
				index1 = 3;
			}
			this.$refs[itemKey][index0].style.color = colorList[0];
			this.$refs[itemKey][index1].style.color = colorList[1];
		},
		// 排序点击操作功能，参数row：item列对象
		handleSort(row) {
			if (!row.sort) return;                 // 不排序
			const key = row.key;                   // 点击列的key
			// 排序列头项: 默认0， 1：升序  2：降序
			this.sortList.forEach(item => {
				const refs = this.$refs[item.key]; // 获取当前排序箭头按钮所在的dom对象
				refs.forEach(i => {
					i.style.color = '#FFFFFF';     // 设置图标颜色（上下两个箭头）：初始化都默认置为白色
				});
				if (item.key === key) {            // 当前操作列的key
					var curkey = key === 'name' ? 'nameCode' : key;
					curkey = this.getNameToCodeCurkey(key); // 特殊处理部分字段name的code取值,即常用的枚举类型
					item.sort++;
					if (item.sort > 2) item.sort = 0;       // 超过2时，重置默认0状态，出现上下俩箭头
					if (item.sort === 0) {                  // 从当前降序状态点击，展示到默认状态
						this.sortFun(JSON.parse(JSON.stringify(this.moduleList)));
					} else {
						let sortObj = {}, colorList = [];
						if (item.sort === 1) {                   // 从当前默认状态点击，展示到升序状态
							sortObj = { key: curkey, sort: 'up' };
							colorList = ['#ffffff', '#1F96F4'];
						}
						if (item.sort === 2) {                   // 从当前升序状态点击，展示到降序状态
							sortObj = { key: curkey, sort: 'down' };
							colorList = ['#1F96F4', '#ffffff'];
						}
						this.sortFun(JSON.parse(JSON.stringify(this.dataList)), sortObj);
						this.setSortArrowStyle(item.key, row.fixed, colorList);
					}
					if (this.showTotal) {                        // 显示总计/合计行信息
						this.dataList.unshift(this.totalValue);  // 总计添加到顶部方法将新项添加到数组的开头
					}
				}
			});
		},
		// 排序逻辑处理功能
		sortFun(newValue, sort = this.defaultSort) {
			let data = this.showTotal ? newValue.filter(i => i.nameCode !== 'total') : newValue;
			if (sort) {
				let arr_list = data.filter(z => z[sort.key] == '-');                  // 数据为空- 的数组
				let arr_list1 = data.filter(z => z[sort.key] != '-');                 // 数据不为空- 的数组
				let newdata = sort.sort === 'up' ?
					arr_list1.sort((a, b) => a[sort.key] - b[sort.key]) :
					arr_list1.sort((a, b) => b[sort.key] - a[sort.key]);
				this.dataList = [...newdata, ...arr_list];     // 把排序后的数组和数据为空的数组重新组合展示                  
			} else {                                           // 默认状态：不排序
				this.dataList = data;                          // Vue.set(this.dataList,data);
			};
		},
		// 注册并设置加载更多监听功能
		loadMoreListener() {
			const selectWrap = document.querySelector('.el-table__body-wrapper');
			selectWrap.addEventListener('scroll', () => {
				const scrollDistance = selectWrap.scrollHeight - selectWrap.scrollTop - selectWrap.clientHeight;
				// console.log('scrollDistance值: '+scrollDistance);
				// 同时满足以下情况，加载下一页
				// 1.页面滑动到底部，即scrollDistance = 0
				// 2.页面有滑动的情况，即selectWrap.scrollHeight > selectWrap.clientHeight
				if (scrollDistance <= 2 && selectWrap.scrollHeight > selectWrap.clientHeight) {
					this.$emit('loadmore');         // 加载更多
				}
			})
		},
	},
	mounted() {
		if (this.isLoadMore) {                      // 加载更多
			this.loadMoreListener();
		}
	},
	template: `<div class="customTableTemp">
        <el-table :data="dataList"
            :ref="refName" stripe border
            :header-cell-style="{background:'rgb(31, 150, 244)',color:'#FFFFFF', height: headStyle['line-height'] ? headStyle['line-height'] : '46px', 'text-align': 'center'}"
            :row-style="{height:'46px'}" :height="tableHeight" style="width: 100%"
        >
        	<template v-for="item in tableColumn">
                <el-table-column :prop="item.key" :min-width="item.width" :fixed="item.fixed"
                    :align="item.align ? item.align : 'right'"  
                >
                    <template slot="header" slot-scope="scope">
                        <div @click="handleSort(item)" class="table-sort" :style="{'justify-content': translateTextAlign(item), ...headStyle}" style="width: 100%;">
                            <span v-html="item.name" class="tableSortSpan" :style="item.colHeadStyle"></span>
                            <div v-if="item.sort" class="table-sort-icon" style="color:#ffffff">
                                <i :ref="item.key" class="el-icon-caret-top"></i>
                                <i :ref="item.key" class="el-icon-caret-bottom"></i>
                            </div>
                        </div>
                    </template>
                    <template slot-scope="scope">
                        <div @click="handleClick(item, scope.row)" v-if="item.key !== 'operate'" :style="setRowStyle(item.align)">
                            <span v-if="item.key === 'no'">{{getNo(scope.$index)}}</span>
                            <span v-else style="display: block;" :style="{color: getColor(item, scope.row), 'margin-right': item.sort ? '10px' : '0'}">
								{{getSpanValue(scope.row[item.key],item.filter)}}
                            </span>
                        </div>
                        <slot v-else :row="scope.row"></slot>
                    </template>
                </el-table-column>
            </template>
        </el-table>
    </div>`
});
