// 路向表格组件
Vue.component('road-sheet', {
	data() {
		return {
			sheetList: [],               // 表格列表数据(界面展示)
			sheetOriList: [],            // 表格列表数据(接口返回原数组)
			sheetOriLength: true,        // 表格列表长度(接口返回原数组)
			rowMoreDataFlag: false,      // 是否展示更多数据标识，默认：false: 不展开
		}
	},
	props: {
		// 表格列表-表头
		roadHeader: {
			Array,
			default: () => { return [] }
		},
	},
	methods: {
		// 查看更多-展开功能(展示全部数据)
		lookMoreOpen() {
			this.rowMoreDataFlag = true;      // 展示-更多数据内容
			this.sheetList = this.sheetOriList;
		},
		// 查看更多-收起功能(只展示一条数据)
		lookMoreFold(sheetData) {
			this.sheetOriLength = true;       // 折叠按钮展示标识，初始化默认展示
			this.rowMoreDataFlag = false;     // 展示-收起数据内容
			if (sheetData) {
				this.sheetOriList = sheetData;
			}
			if (this.sheetOriList.length > 0) {
				this.sheetList = this.sheetOriList.slice(0, 1);    // 获取数组第一条数据，并且不改变原数组
				if (this.sheetOriList.length == 1) {
					this.sheetOriLength = false;                   // 原数组仅有一条数据时，不展示折叠按钮
				}
			}
			if (this.sheetOriList.length == 0) {
				this.sheetOriLength = false;                       // 原数组为空时，不展示折叠按钮
				this.sheetList = [];                               // 展示数组置为空, 清空上次数据
			}
		},
	},
	// 渲染组件界面
	template: `<div>
		<div class="roadRowBlock">
			<div class="roadRow">
				<div v-for="headerItem in roadHeader" class="roadRowItem roadRowHeader">
					<div class="roadRowTitle">{{headerItem}}</div>
				</div>
			</div>
			<div v-for="item in sheetList" class="roadRow">
				<div class="roadRowItem roadRowItemName">
					<div class="roadRowTitle">{{item.roadName}}</div>
				</div>
				<div class="roadRowItem">
					<div class="roadRowColor" :style="{color: getWordColor(item.roadFirstCol)}">
						{{nullToZero(item.roadFirstCol)}}
					</div>
				</div>
				<div class="roadRowItem">
					<div class="roadRowColor" :style="{color: getWordColor(item.roadSecondCol)}">
						{{nullToZero(item.roadSecondCol)}}
					</div>
				</div>
			</div>
			<div v-if="sheetList.length == 0" class="noDataRow">
				暂无数据
			</div>
		</div>
		<div v-if="sheetOriLength" class="lookMoreBlock">
			<div v-if="!rowMoreDataFlag" @click="lookMoreOpen()">
				查看更多<img src="../../img/icon/down_arrow.png" class="moreArrow" alt="" />
			</div>
			<div v-else-if="rowMoreDataFlag" @click="lookMoreFold()">
				收起<img src="../../img/icon/up_arrow.png" class="moreArrow" alt="" />
			</div>
		</div>
	</div>`
});

// 设备效能表格组件
Vue.component('equipment-sheet', {
	data() {
		return {
			equipmentShowList: [],       //表格展示的数据
			equipmentAllList: [],        //表格全部的数据
			equipmentAllLength: true,    // 表格列表长度(接口返回原数组)
			rowMoreDataFlag: false,      // 是否展示更多数据标识，默认：false: 不展开
		}
	},
	methods: {
		// 查看更多-展开功能(展示全部数据)
		lookMoreOpen() {
			this.rowMoreDataFlag = true;      // 展示-更多数据内容
			this.equipmentShowList = this.equipmentAllList;
		},
		// 查看更多-收起功能(只展示一条数据)
		lookMoreFold(equipmentData) {
			this.rowMoreDataFlag = false;     // 展示-收起数据内容
			if (equipmentData) {
				this.equipmentAllList = equipmentData;
			}
			if (this.equipmentAllList.length > 0) {
				this.equipmentShowList = this.equipmentAllList.slice(0, 1);    // 获取第一组，并且不改变原数组
			}
			if (this.equipmentAllList.length == 1) {
				this.equipmentAllLength = false;                      // 原数组仅有一条数据时，不展示折叠按钮
			}
		},
	},
	// 内容超出高度滚动class,放到第一行 blockContItemScroll
	template: `
		<div class="blockContItem">
			<div class="blockContItemCon" v-for="(ob,index) in equipmentShowList">
				<div class="blockContItemTitle">
					<img src="../../img/icon/title_arrow.png" class="titleArrow" alt="" />
					{{ob.sortmachineSname}}
				</div>
				<div class="blockContRow contRow3">
					<div class="blockContRowLeft">
						<div class="rowDivTitle">开机时长(分钟)</div>
						<div class="rowDivWord">{{nullToZero(ob.runDuration)}}</div>
					</div>
					<div class="blockContRowRight">
						<div class="rowDivTitle">环比</div>
						<div class="rowDivWord" :style="{color: getWordColor(ob.runDurationHb)}">
							{{nullToZero(ob.runDurationHb)}}%
						</div>
					</div>
				</div>
				<div class="blockContRow contRow2">
					<div class="blockContRowLeft">
						<div class="rowDivTitle">供件效率(袋件)</div>
						<div class="rowDivWord">{{nullToZero(ob.avgRate)}}</div>
					</div>
					<div class="blockContRowRight">
						<div class="rowDivTitle">环比</div>
						<div class="rowDivWord" :style="{color: getWordColor(ob.avgRateHb)}">
							{{nullToZero(ob.avgRateHb)}}%
						</div>
					</div>
				</div>
				<div class="blockContRow contRow2">
					<div class="blockContRowLeft">
						<div class="rowDivTitle">OBR识别率(袋件)</div>
						<div class="rowDivWord">{{nullToZero(ob.obrPrec)}}</div>
					</div>
					<div class="blockContRowRight">
						<div class="rowDivTitle">环比</div>
						<div class="rowDivWord" :style="{color: getWordColor(ob.obrPrecHb)}">
							{{nullToZero(ob.obrPrecHb)}}%
						</div>
					</div>
				</div>
				<div class="blockContRow contRow2">
					<div class="blockContRowLeft">
						<div class="rowDivTitle">收容率(袋件)</div>
						<div class="rowDivWord">{{nullToZero(ob.srRate)}}</div>
					</div>
					<div class="blockContRowRight">
						<div class="rowDivTitle">环比</div>
						<div class="rowDivWord" :style="{color: getWordColor(ob.srRateHb)}">
							{{nullToZero(ob.srRateHb)}}%
						</div>
					</div>
				</div>
				<div class="blockContRow contRow2">
					<div class="blockContRowLeft">
						<div class="rowDivTitle">设备效能</div>
						<div class="rowDivWord">{{nullToZero(ob.sunRate)}}</div>
					</div>
					<div class="blockContRowRight">
						<div class="rowDivTitle">环比</div>
						<div class="rowDivWord" :style="{color: getWordColor(ob.sunHb)}">
							{{nullToZero(ob.sunHb)}}%
						</div>
					</div>
				</div>
				<div class="blockContRow contRow1">
					<div class="blockContRowLeft">
						<div class="rowDivTitle">效能目标</div>
						<div class="rowDivWord">{{nullToZero(ob.effTarget)}}</div>
					</div>
					<div class="blockContRowRight">
						<div class="rowDivTitle">环比</div>
						<div class="rowDivWord" :style="{color: getWordColor(ob.xnmbhb)}">
							{{nullToZero(ob.xnmbhb)}}%
						</div>
					</div>
				</div>
			</div>
			<div v-if="equipmentShowList.length == 0" class="noDataRow">
				暂无数据
			</div>
			<div v-if="equipmentAllLength" class="lookMoreBlock">
				<div v-if="!rowMoreDataFlag" @click="lookMoreOpen()">
					查看更多<img src="../../img/icon/down_arrow.png" class="moreArrow" alt="" />
				</div>
				<div v-else-if="rowMoreDataFlag" @click="lookMoreFold()">
					收起<img src="../../img/icon/up_arrow.png" class="moreArrow" alt="" />
				</div>
			</div>
        </div>
	`
});


